'''
Manage MySQL servers.
'''
from ... pyaz_utils import _call_az
from . import ad_admin, configuration, firewall_rule, key, private_endpoint_connection, private_link_resource, replica, vnet_rule


def create(admin_password=None, admin_user=None, assign_identity=None, auto_grow=None, backup_retention=None, geo_redundant_backup=None, infrastructure_encryption=None, location=None, minimal_tls_version=None, name=None, public_network_access=None, resource_group=None, sku_name=None, ssl_enforcement=None, storage_size=None, tags=None, version=None):
    '''
    Create a server.

    Optional Parameters:
    - admin_password -- The password of the administrator. Minimum 8 characters and maximum 128 characters. Password must contain characters from three of the following categories: English uppercase letters, English lowercase letters, numbers, and non-alphanumeric characters.
    - admin_user -- Administrator username for the server. Once set, it cannot be changed.
    - assign_identity -- Generate and assign an Azure Active Directory Identity for this server for use with key management services like Azure KeyVault.
    - auto_grow -- Enable or disable autogrow of the storage. Default value is Enabled.
    - backup_retention -- The number of days a backup is retained. Range of 7 to 35 days. Default is 7 days.
    - geo_redundant_backup -- Enable or disable geo-redundant backups. Default value is Disabled. Not supported in Basic pricing tier.
    - infrastructure_encryption -- Add an optional second layer of encryption for data using new encryption algorithm. Default value is Disabled.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - minimal_tls_version -- Set the minimal TLS version for connections to server when SSL is enabled. Default is TLSEnforcementDisabled.
    - name -- Name of the server. The name can contain only lowercase letters, numbers, and the hyphen (-) character. Minimum 3 characters and maximum 63 characters.
    - public_network_access -- Enable or disable public network access to server. When disabled, only connections made through Private Links can reach this server. Allowed values are : Enabled, Disabled, all, 0.0.0.0, <SingleIP>, <StartIP-DestinationIP>. Default is Enabled.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - sku_name -- The name of the sku. Follows the convention {pricing tier}_{compute generation}_{vCores} in shorthand. Examples: B_Gen5_1, GP_Gen5_4, MO_Gen5_16. 
    - ssl_enforcement -- Enable or disable ssl enforcement for connections to server. Default is Enabled.
    - storage_size -- The storage capacity of the server (unit is megabytes). Minimum 5120 and increases in 1024 increments. Default is 51200.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - version -- Server major version.
    '''
    return _call_az("az mysql server create", locals())


def restore(name, resource_group, restore_point_in_time, source_server, no_wait=None):
    '''
    Restore a server from backup.

    Required Parameters:
    - name -- Name of the server. The name can contain only lowercase letters, numbers, and the hyphen (-) character. Minimum 3 characters and maximum 63 characters.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - restore_point_in_time -- The point in time in UTC to restore from (ISO8601 format), e.g., 2017-04-26T02:10:00+08:00
    - source_server -- The name or resource ID of the source server to restore from.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az mysql server restore", locals())


def georestore(location, name, resource_group, source_server, backup_retention=None, geo_redundant_backup=None, no_wait=None, sku_name=None):
    '''
    Geo-restore a server from backup.

    Required Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - name -- Name of the server. The name can contain only lowercase letters, numbers, and the hyphen (-) character. Minimum 3 characters and maximum 63 characters.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - source_server -- The name or ID of the source server to restore from.

    Optional Parameters:
    - backup_retention -- The number of days a backup is retained. Range of 7 to 35 days. Default is 7 days.
    - geo_redundant_backup -- Enable or disable geo-redundant backups. Default value is Disabled. Not supported in Basic pricing tier.
    - no_wait -- Do not wait for the long-running operation to finish.
    - sku_name -- The name of the sku. Defaults to sku of the source server. Follows the convention {pricing tier}_{compute generation}_{vCores} in shorthand. Examples: B_Gen5_1, GP_Gen5_4, MO_Gen5_16.
    '''
    return _call_az("az mysql server georestore", locals())


def delete(name, resource_group, yes=None):
    '''
    Delete a server.

    Required Parameters:
    - name -- Name of the server. The name can contain only lowercase letters, numbers, and the hyphen (-) character. Minimum 3 characters and maximum 63 characters.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az mysql server delete", locals())


def show(name, resource_group):
    '''
    Get the details of a server.

    Required Parameters:
    - name -- Name of the server. The name can contain only lowercase letters, numbers, and the hyphen (-) character. Minimum 3 characters and maximum 63 characters.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az mysql server show", locals())


def list(resource_group=None):
    '''
    List available servers.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az mysql server list", locals())


def update(name, resource_group, add=None, admin_password=None, assign_identity=None, auto_grow=None, backup_retention=None, force_string=None, minimal_tls_version=None, public_network_access=None, remove=None, set=None, sku_name=None, ssl_enforcement=None, storage_size=None, tags=None):
    '''
    Update a server.

    Required Parameters:
    - name -- Name of the server. The name can contain only lowercase letters, numbers, and the hyphen (-) character. Minimum 3 characters and maximum 63 characters.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - admin_password -- The password of the administrator. Minimum 8 characters and maximum 128 characters. Password must contain characters from three of the following categories: English uppercase letters, English lowercase letters, numbers, and non-alphanumeric characters.
    - assign_identity -- Generate and assign an Azure Active Directory Identity for this server for use with key management services like Azure KeyVault.
    - auto_grow -- Enable or disable autogrow of the storage. Default value is Enabled.
    - backup_retention -- The number of days a backup is retained. Range of 7 to 35 days. Default is 7 days.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - minimal_tls_version -- Set the minimal TLS version for connections to server when SSL is enabled. Default is TLSEnforcementDisabled.
    - public_network_access -- Enable or disable public network access to server. When disabled, only connections made through Private Links can reach this server. Allowed values are : Enabled, Disabled, all, 0.0.0.0, <SingleIP>, <StartIP-DestinationIP>. Default is Enabled.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - sku_name -- The name of the sku. Follows the convention {pricing tier}_{compute generation}_{vCores} in shorthand. Examples: B_Gen5_1, GP_Gen5_4, MO_Gen5_16.
    - ssl_enforcement -- Enable or disable ssl enforcement for connections to server. Default is Enabled.
    - storage_size -- The storage capacity of the server (unit is megabytes). Minimum 5120 and increases in 1024 increments. Default is 51200.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az mysql server update", locals())


def wait(name, resource_group, custom=None, exists=None, interval=None, timeout=None):
    '''
    Wait for server to satisfy certain conditions.

    Required Parameters:
    - name -- Name of the server. The name can contain only lowercase letters, numbers, and the hyphen (-) character. Minimum 3 characters and maximum 63 characters.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    '''
    return _call_az("az mysql server wait", locals())


def restart(name, resource_group):
    '''
    Restart a server.

    Required Parameters:
    - name -- Name of the server. The name can contain only lowercase letters, numbers, and the hyphen (-) character. Minimum 3 characters and maximum 63 characters.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az mysql server restart", locals())


def start(name, resource_group):
    '''
    Start a stopped server.

    Required Parameters:
    - name -- Name of the server. The name can contain only lowercase letters, numbers, and the hyphen (-) character. Minimum 3 characters and maximum 63 characters.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az mysql server start", locals())


def stop(name, resource_group):
    '''
    Stop a running server.

    Required Parameters:
    - name -- Name of the server. The name can contain only lowercase letters, numbers, and the hyphen (-) character. Minimum 3 characters and maximum 63 characters.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az mysql server stop", locals())


def upgrade(name, resource_group, target_server_version):
    '''
    Upgrade mysql server to a higher version, like 5.6 to 5.7.

    Required Parameters:
    - name -- Name of the server. The name can contain only lowercase letters, numbers, and the hyphen (-) character. Minimum 3 characters and maximum 63 characters.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - target_server_version -- The server version you want to upgrade your mysql server to, currently only support 5.7.
    '''
    return _call_az("az mysql server upgrade", locals())


def list_skus(location):
    '''
    List available sku's in the given region.

    Required Parameters:
    - location -- The name of the location.
    '''
    return _call_az("az mysql server list-skus", locals())


def show_connection_string(admin_password=None, admin_user=None, database_name=None, server_name=None):
    '''
    Show the connection strings for a MySQL server database.

    Optional Parameters:
    - admin_password -- The login password of the administrator.
    - admin_user -- The login username of the administrator.
    - database_name -- The name of a database.
    - server_name -- Name of the server.
    '''
    return _call_az("az mysql server show-connection-string", locals())




'''
Manage projects for an instance of the Data Migration Service.
'''
from ... pyaz_utils import _call_az
from . import task


def create(location, name, resource_group, service_name, source_platform, target_platform, tags=None):
    '''
    Create a migration project which can contain multiple tasks.

    Required Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - name -- The name of the Project.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_name -- The name of the Service.
    - source_platform -- None
    - target_platform -- None

    Optional Parameters:
    - tags -- A space-delimited list of tags in "tag1[=value1]" format.
    '''
    return _call_az("az dms project create", locals())


def delete(name, resource_group, service_name, delete_running_tasks=None, yes=None):
    '''
    Delete a project.

    Required Parameters:
    - name -- The name of the Project.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_name -- The name of the Service.

    Optional Parameters:
    - delete_running_tasks -- Delete the resource even if it contains running tasks.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az dms project delete", locals())


def list(resource_group, service_name):
    '''
    List the projects within an instance of DMS.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_name -- The name of the Service.
    '''
    return _call_az("az dms project list", locals())


def show(name, resource_group, service_name):
    '''
    Show the details of a migration project.

    Required Parameters:
    - name -- The name of the Project.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_name -- The name of the Service.
    '''
    return _call_az("az dms project show", locals())


def check_name(name, resource_group, service_name):
    '''
    Check if a given project name is available within a given instance of DMS as well as the name's validity.

    Required Parameters:
    - name -- The name of the Project.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_name -- The name of the Service.
    '''
    return _call_az("az dms project check-name", locals())




'''
Manage Azure Active Directory users and user authentication.
'''
from ... pyaz_utils import _call_az

def delete(id):
    '''
    

    Required Parameters:
    - id -- The object ID or principal name of the user for which to get information
    '''
    return _call_az("az ad user delete", locals())


def show(id):
    '''
    

    Required Parameters:
    - id -- The object ID or principal name of the user for which to get information
    '''
    return _call_az("az ad user show", locals())


def list(display_name=None, filter=None, upn=None):
    '''
    List Azure Active Directory users.

    Optional Parameters:
    - display_name -- object's display name or its prefix
    - filter -- OData filter, e.g. --filter "displayname eq 'test' and servicePrincipalType eq 'Application'"
    - upn -- user principal name, e.g. john.doe@contoso.com
    '''
    return _call_az("az ad user list", locals())


def get_member_groups(id, security_enabled_only=None):
    '''
    Get groups of which the user is a member

    Required Parameters:
    - id -- The object ID or principal name of the user for which to get information

    Optional Parameters:
    - security_enabled_only -- If true, only membership in security-enabled groups should be checked. Otherwise, membership in all groups should be checked.
    '''
    return _call_az("az ad user get-member-groups", locals())


def create(display_name, password, user_principal_name, force_change_password_next_login=None, immutable_id=None, mail_nickname=None):
    '''
    Create an Azure Active Directory user.

    Required Parameters:
    - display_name -- object's display name or its prefix
    - password -- user password
    - user_principal_name -- Required. The user principal name (someuser@contoso.com). It must contain one of the verified domains for the tenant.

    Optional Parameters:
    - force_change_password_next_login -- Require the user to change their password the next time they log in. Only valid when --password is specified
    - immutable_id -- This must be specified if you are using a federated domain for the user's userPrincipalName (UPN) property when creating a new user account. It is used to associate an on-premises Active Directory user account with their Azure AD user object.
    - mail_nickname -- mail alias. Defaults to user principal name
    '''
    return _call_az("az ad user create", locals())


def update(id, account_enabled=None, display_name=None, force_change_password_next_login=None, mail_nickname=None, password=None):
    '''
    Update Azure Active Directory users.

    Required Parameters:
    - id -- The object ID or principal name of the user for which to get information

    Optional Parameters:
    - account_enabled -- enable the user account
    - display_name -- object's display name or its prefix
    - force_change_password_next_login -- Require the user to change their password the next time they log in. Only valid when --password is specified
    - mail_nickname -- mail alias. Defaults to user principal name
    - password -- user password
    '''
    return _call_az("az ad user update", locals())




from .... pyaz_utils import _call_az

def create(account_name, name, require_infrastructure_encryption=None, resource_group=None):
    '''
    Create an encryption scope within storage account.

    Required Parameters:
    - account_name -- The storage account name.
    - name -- The name of the encryption scope within the specified storage account.

    Optional Parameters:
    - require_infrastructure_encryption -- A boolean indicating whether or not the service applies a secondary layer of encryption with platform managed keys for data at rest.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az storage account encryption-scope create", locals())


def show(account_name, name, resource_group=None):
    '''
    Show properties for specified encryption scope within storage account.

    Required Parameters:
    - account_name -- The storage account name.
    - name -- The name of the encryption scope within the specified storage account.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az storage account encryption-scope show", locals())


def list(account_name, resource_group=None):
    '''
    List encryption scopes within storage account.

    Required Parameters:
    - account_name -- The storage account name.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az storage account encryption-scope list", locals())


def update(account_name, name, resource_group=None, state=None):
    '''
    Update properties for specified encryption scope within storage account.

    Required Parameters:
    - account_name -- The storage account name.
    - name -- The name of the encryption scope within the specified storage account.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - state -- Change the state the encryption scope. When disabled, all blob read/write operations using this encryption scope will fail.
    '''
    return _call_az("az storage account encryption-scope update", locals())




from ...... pyaz_utils import _call_az
from . import rule_set


def add(match_variable, policy_name, resource_group, selector, selector_match_operator):
    '''
    Add an OWASP CRS exclusion rule to the WAF policy managed rules.

    Required Parameters:
    - match_variable -- The variable to be excluded.
    - policy_name -- The name of the web application firewall policy.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - selector -- When matchVariable is a collection, operator used to specify which elements in the collection this exclusion applies to.
    - selector_match_operator -- When matchVariable is a collection, operate on the selector to specify which elements in the collection this exclusion applies to.
    '''
    return _call_az("az network application-gateway waf-policy managed-rule exclusion add", locals())


def remove(policy_name, resource_group):
    '''
    Remove all OWASP CRS exclusion rules that are applied on a Waf policy managed rules.

    Required Parameters:
    - policy_name -- The name of the web application firewall policy.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network application-gateway waf-policy managed-rule exclusion remove", locals())


def list(policy_name, resource_group):
    '''
    List all OWASP CRS exclusion rules that are applied on a Waf policy managed rules.

    Required Parameters:
    - policy_name -- The name of the web application firewall policy.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network application-gateway waf-policy managed-rule exclusion list", locals())




'''
Manage DNS zones.
'''
from .... pyaz_utils import _call_az

def delete(name, resource_group, if_match=None, yes=None):
    '''
    Delete a DNS zone and all associated records.

    Required Parameters:
    - name -- The name of the zone.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - if_match -- The etag of the DNS zone. Omit this value to always delete the current zone. Specify the last-seen etag value to prevent accidentally deleting any concurrent changes.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az network dns zone delete", locals())


def show(name, resource_group):
    '''
    Get a DNS zone parameters. Does not show DNS records within the zone.

    Required Parameters:
    - name -- The name of the zone.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network dns zone show", locals())


def list(resource_group=None):
    '''
    List DNS zones.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network dns zone list", locals())


def import_(file_name, name, resource_group):
    '''
    Create a DNS zone using a DNS zone file.

    Required Parameters:
    - file_name -- Path to the DNS zone file to import
    - name -- The name of the zone.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network dns zone import", locals())


def export(name, resource_group, file_name=None):
    '''
    Export a DNS zone as a DNS zone file.

    Required Parameters:
    - name -- The name of the zone.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - file_name -- Path to the DNS zone file to save
    '''
    return _call_az("az network dns zone export", locals())


def create(name, resource_group, if_none_match=None, parent_name=None, registration_vnets=None, resolution_vnets=None, tags=None, zone_type=None):
    '''
    Create a DNS zone.

    Required Parameters:
    - name -- The name of the zone.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - if_none_match -- None
    - parent_name -- Specify if parent zone exists for this zone and delegation for the child zone in the parent is to be added.
    - registration_vnets -- Space-separated names or IDs of virtual networks that register hostnames in this DNS zone. Number of private DNS zones with virtual network auto-registration enabled is 1. If you need to increase this limit, please contact Azure Support: https://docs.microsoft.com/en-us/azure/azure-subscription-service-limits
    - resolution_vnets -- Space-separated names or IDs of virtual networks that resolve records in this DNS zone.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - zone_type -- Type of DNS zone to create.
    '''
    return _call_az("az network dns zone create", locals())


def update(name, resource_group, add=None, force_string=None, if_match=None, registration_vnets=None, remove=None, resolution_vnets=None, set=None, tags=None, zone_type=None):
    '''
    Update a DNS zone properties. Does not modify DNS records within the zone.

    Required Parameters:
    - name -- The name of the zone.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - if_match -- The etag of the DNS zone. Omit this value to always overwrite the current zone. Specify the last-seen etag value to prevent accidentally overwriting any concurrent changes.
    - registration_vnets -- Space-separated names or IDs of virtual networks that register hostnames in this DNS zone. Number of private DNS zones with virtual network auto-registration enabled is 1. If you need to increase this limit, please contact Azure Support: https://docs.microsoft.com/en-us/azure/azure-subscription-service-limits
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - resolution_vnets -- Space-separated names or IDs of virtual networks that resolve records in this DNS zone.
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - zone_type -- Type of DNS zone to create.
    '''
    return _call_az("az network dns zone update", locals())




from ... pyaz_utils import _call_az

def list(name, resource_group=None):
    '''
    list the private link resources supported for a registry

    Required Parameters:
    - name -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az acr private-link-resource list", locals())




from .... pyaz_utils import _call_az
from . import ipsec_policy


def generate(name, resource_group, authentication_method=None, client_root_certificates=None, processor_architecture=None, radius_server_auth_certificate=None, use_legacy=None):
    '''
    Generate VPN client configuration.

    Required Parameters:
    - name -- Name of the VNet gateway.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - authentication_method -- Method used to authenticate with the generated client.
    - client_root_certificates -- Space-separated list of client root certificate public certificate data in Base-64 format. Optional for external Radius-based auth with EAPTLS
    - processor_architecture -- Processor architecture of the target system.
    - radius_server_auth_certificate -- Public certificate data for the Radius server auth certificate in Base-64 format. Required only if external Radius auth has been configured with EAPTLS auth.
    - use_legacy -- Generate VPN client package using legacy implementation.
    '''
    return _call_az("az network vnet-gateway vpn-client generate", locals())


def show_url(name, resource_group):
    '''
    Retrieve a pre-generated VPN client configuration.

    Required Parameters:
    - name -- Name of the VNet gateway.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network vnet-gateway vpn-client show-url", locals())


def show_health(name, resource_group):
    '''
    Get the VPN client connection health detail per P2S client connection of the virtual network gateway.

    Required Parameters:
    - name -- Name of the VNet gateway.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network vnet-gateway vpn-client show-health", locals())




'''
Manage HDInsight applications.
'''
from ... pyaz_utils import _call_az

def create(cluster_name, name, resource_group, script_action_name, script_uri, access_mode=None, destination_port=None, disable_gateway_auth=None, edgenode_size=None, marketplace_id=None, no_validation_timeout=None, script_parameters=None, ssh_password=None, ssh_public_key=None, ssh_user=None, sub_domain_suffix=None, subnet=None, tags=None, type=None, vnet_name=None):
    '''
    Create an application for a HDInsight cluster.

    Required Parameters:
    - cluster_name -- The name of the cluster.
    - name -- The constant value for the application name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - script_action_name -- The name of the script action.
    - script_uri -- The URI to the script.

    Optional Parameters:
    - access_mode -- The access mode for the application.
    - destination_port -- The destination port to connect to.
    - disable_gateway_auth -- Indicates whether to disable gateway authentication. Default is to enable gateway authentication. Default: false. 
    - edgenode_size -- The size of the node. See also: https://docs.microsoft.com/azure/hdinsight/hdinsight-hadoop-provision-linux-clusters#configure-cluster-size
    - marketplace_id -- The marketplace identifier.
    - no_validation_timeout -- Permit timeout error during argument validation phase. If omitted, validation timeout error will be permitted.
    - script_parameters -- The parameters for the script.
    - ssh_password -- SSH password for the cluster nodes.
    - ssh_public_key -- SSH public key for the cluster nodes.
    - ssh_user -- SSH username for the cluster nodes.
    - sub_domain_suffix -- The subdomain suffix of the application.
    - subnet -- The name or ID of subnet. If name is supplied, `--vnet-name` must be supplied.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - type -- The application type.
    - vnet_name -- The name of a virtual network.
    '''
    return _call_az("az hdinsight application create", locals())


def show(cluster_name, name, resource_group):
    '''
    

    Required Parameters:
    - cluster_name -- The name of the cluster.
    - name -- The constant value for the application name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az hdinsight application show", locals())


def list(cluster_name, resource_group):
    '''
    

    Required Parameters:
    - cluster_name -- The name of the cluster.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az hdinsight application list", locals())


def wait(cluster_name, name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until an operation is complete.

    Required Parameters:
    - cluster_name -- The name of the cluster.
    - name -- The constant value for the application name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az hdinsight application wait", locals())


def delete(cluster_name, name, resource_group, no_wait=None, yes=None):
    '''
    

    Required Parameters:
    - cluster_name -- The name of the cluster.
    - name -- The constant value for the application name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az hdinsight application delete", locals())




'''
Manage Azure Event Hubs namespaces, eventhubs, consumergroups and geo recovery configurations - Alias
'''
from .. pyaz_utils import _call_az
from . import cluster, eventhub, georecovery_alias, namespace




from ... pyaz_utils import _call_az
from . import site, sku


def create(name, resource_group, scale_unit, vendor, version, vhub, asn=None, boot_strap_config_blobs=None, cloud_init_config=None, cloud_init_config_blobs=None, location=None, tags=None):
    '''
    Create an Azure network virtual appliance.

    Required Parameters:
    - name -- The name of Network Virtual Appliance
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - scale_unit -- Virtual Appliance Scale Unit.
    - vendor -- Virtual Appliance Vendor.
    - version -- Virtual Appliance Version.
    - vhub -- Name or ID of the virtual hub to which the Security Partner Provider belongs.

    Optional Parameters:
    - asn -- VirtualAppliance ASN. The valid value ranges from 1 to 4294967295. 
    - boot_strap_config_blobs -- Space-separated list of BootStrapConfigurationBlobs storage URLs.
    - cloud_init_config -- CloudInitConfiguration scripts that will be run during cloud initialization
    - cloud_init_config_blobs -- Space-separated list of CloudInitConfigurationBlob storage URLs.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az network virtual-appliance create", locals())


def update(name, resource_group, add=None, asn=None, cloud_init_config=None, force_string=None, remove=None, set=None):
    '''
    Update an Azure network virtual appliance.

    Required Parameters:
    - name -- The name of Network Virtual Appliance
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - asn -- VirtualAppliance ASN. The valid value ranges from 1 to 4294967295. 
    - cloud_init_config -- CloudInitConfiguration scripts that will be run during cloud initialization
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    '''
    return _call_az("az network virtual-appliance update", locals())


def show(name, resource_group, expand=None):
    '''
    Show the detail of an Azure network virtual appliance.

    Required Parameters:
    - name -- The name of Network Virtual Appliance
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - expand -- Expands referenced resources.
    '''
    return _call_az("az network virtual-appliance show", locals())


def list(resource_group=None):
    '''
    List all Azure network virtual appliance.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network virtual-appliance list", locals())


def delete(name, resource_group, yes=None):
    '''
    Delete an Azure network virtual appliance.

    Required Parameters:
    - name -- The name of Network Virtual Appliance
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az network virtual-appliance delete", locals())




'''
Manage Azure Resource Manager deployments.
'''
from ... pyaz_utils import _call_az
from . import operation


def create(resource_group, aux_subs=None, aux_tenants=None, handle_extended_json_format=None, mode=None, name=None, no_prompt=None, no_wait=None, parameters=None, rollback_on_error=None, template_file=None, template_uri=None):
    '''
    Start a deployment.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - aux_subs -- Auxiliary subscriptions which will be used during deployment across tenants.
    - aux_tenants -- Auxiliary tenants which will be used during deployment across tenants.
    - handle_extended_json_format -- Support to handle extended template content including multiline and comments in deployment
    - mode -- Incremental (only add resources to resource group) or Complete (remove extra resources from resource group)
    - name -- The deployment name. Default to template file base name
    - no_prompt -- The option to disable the prompt of missing parameters for ARM template. When the value is true, the prompt requiring users to provide missing parameter will be ignored. The default value is false.
    - no_wait -- Do not wait for the long-running operation to finish.
    - parameters -- the deployment parameters
    - rollback_on_error -- The name of a deployment to roll back to on error, or use as a flag to roll back to the last successful deployment.
    - template_file -- a path to a template file or Bicep file in the file system
    - template_uri -- a uri to a remote template file
    '''
    return _call_az("az group deployment create", locals())


def list(resource_group, filter=None, top=None):
    '''
    

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - filter -- The filter to apply on the operation. For example, you can use $filter=provisioningState eq '{state}'.
    - top -- The number of results to get. If null is passed, returns all deployments.
    '''
    return _call_az("az group deployment list", locals())


def show(name, resource_group):
    '''
    

    Required Parameters:
    - name -- The deployment name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az group deployment show", locals())


def delete(name, resource_group, no_wait=None):
    '''
    

    Required Parameters:
    - name -- The deployment name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az group deployment delete", locals())


def validate(resource_group, handle_extended_json_format=None, mode=None, no_prompt=None, parameters=None, rollback_on_error=None, template_file=None, template_uri=None):
    '''
    Validate whether a template is syntactically correct.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - handle_extended_json_format -- Support to handle extended template content including multiline and comments in deployment
    - mode -- Incremental (only add resources to resource group) or Complete (remove extra resources from resource group)
    - no_prompt -- The option to disable the prompt of missing parameters for ARM template. When the value is true, the prompt requiring users to provide missing parameter will be ignored. The default value is false.
    - parameters -- the deployment parameters
    - rollback_on_error -- The name of a deployment to roll back to on error, or use as a flag to roll back to the last successful deployment.
    - template_file -- a path to a template file or Bicep file in the file system
    - template_uri -- a uri to a remote template file
    '''
    return _call_az("az group deployment validate", locals())


def export(name, resource_group):
    '''
    Export the template used for a deployment.

    Required Parameters:
    - name -- The deployment name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az group deployment export", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a deployment condition is met.

    Required Parameters:
    - name -- The deployment name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az group deployment wait", locals())


def cancel(name, resource_group):
    '''
    

    Required Parameters:
    - name -- The deployment name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az group deployment cancel", locals())




from ... pyaz_utils import _call_az

def invoke(command_id, name, resource_group, parameters=None, scripts=None):
    '''
    Execute a specific run command on a vm.

    Required Parameters:
    - command_id -- The command id. Use 'az vm run-command list' to get the list
    - name -- The name of the Virtual Machine. You can configure the default using `az configure --defaults vm=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - parameters -- space-separated parameters in the format of '[name=]value'
    - scripts -- Space-separated script lines. Use @{file} to load script from a file
    '''
    return _call_az("az vm run-command invoke", locals())


def list(expand=None, location=None, resource_group=None, vm_name=None):
    '''
    The operation to get all run commands of a Virtual Machine. And Lists all available run commands for a subscription in a location.

    Optional Parameters:
    - expand -- The expand expression to apply on the operation.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vm_name -- The name of the virtual machine
    '''
    return _call_az("az vm run-command list", locals())


def show(command_id=None, expand=None, instance_view=None, location=None, name=None, resource_group=None, vm_name=None):
    '''
    The operation to get the run command. And Gets specific run command for a subscription in a location.

    Optional Parameters:
    - command_id -- The command id.
    - expand -- The expand expression to apply on the operation.
    - instance_view -- Track the run command progress
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - name -- The name of the virtual machine run command.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vm_name -- The name of the virtual machine
    '''
    return _call_az("az vm run-command show", locals())


def create(name, resource_group, vm_name, async_execution=None, command_id=None, error_blob_uri=None, location=None, no_wait=None, output_blob_uri=None, parameters=None, protected_parameters=None, run_as_password=None, run_as_user=None, script=None, script_uri=None, tags=None, timeout_in_seconds=None):
    '''
    The operation to create the run command.

    Required Parameters:
    - name -- The name of the virtual machine run command.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vm_name -- The name of the virtual machine

    Optional Parameters:
    - async_execution -- Optional. If set to true, provisioning will complete as soon as the script starts and will not wait for script to complete.
    - command_id -- Specify a command id of predefined script. All command ids can be listed using "list" command.
    - error_blob_uri -- Specify the Azure storage blob where script error stream will be uploaded.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - no_wait -- Do not wait for the long-running operation to finish.
    - output_blob_uri -- Specify the Azure storage blob where script output stream will be uploaded.
    - parameters -- Set custom parameters in a name-value pair.
    - protected_parameters -- Set custom parameters in a name-value pair. These parameters will be encrypted during transmission and will not be logged.
    - run_as_password -- Password if needed for using run-as-user parameter. It will be encrypted and not logged. 
    - run_as_user -- By default script process runs under system/root user. Specify custom user to host the process.
    - script -- Contain the powershell or bash script to execute on the VM.
    - script_uri -- Contain a uri to the script to execute on the VM. Uri can be any link accessible from the VM or a storage blob without SAS. If subscription has access to the storage blob, then SAS will be auto-generated. 
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - timeout_in_seconds -- The timeout in seconds to execute the run command.
    '''
    return _call_az("az vm run-command create", locals())


def update(name, resource_group, vm_name, async_execution=None, command_id=None, error_blob_uri=None, location=None, no_wait=None, output_blob_uri=None, parameters=None, protected_parameters=None, run_as_password=None, run_as_user=None, script=None, script_uri=None, tags=None, timeout_in_seconds=None):
    '''
    The operation to update the run command.

    Required Parameters:
    - name -- The name of the virtual machine run command.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vm_name -- The name of the virtual machine

    Optional Parameters:
    - async_execution -- Optional. If set to true, provisioning will complete as soon as the script starts and will not wait for script to complete.
    - command_id -- Specify a command id of predefined script. All command ids can be listed using "list" command.
    - error_blob_uri -- Specify the Azure storage blob where script error stream will be uploaded.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - no_wait -- Do not wait for the long-running operation to finish.
    - output_blob_uri -- Specify the Azure storage blob where script output stream will be uploaded.
    - parameters -- Set custom parameters in a name-value pair.
    - protected_parameters -- Set custom parameters in a name-value pair. These parameters will be encrypted during transmission and will not be logged.
    - run_as_password -- Password if needed for using run-as-user parameter. It will be encrypted and not logged. 
    - run_as_user -- By default script process runs under system/root user. Specify custom user to host the process.
    - script -- Contain the powershell or bash script to execute on the VM.
    - script_uri -- Contain a uri to the script to execute on the VM. Uri can be any link accessible from the VM or a storage blob without SAS. If subscription has access to the storage blob, then SAS will be auto-generated. 
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - timeout_in_seconds -- The timeout in seconds to execute the run command.
    '''
    return _call_az("az vm run-command update", locals())


def delete(name, resource_group, vm_name, no_wait=None, yes=None):
    '''
    The operation to delete the run command.

    Required Parameters:
    - name -- The name of the virtual machine run command.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vm_name -- The name of the virtual machine

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az vm run-command delete", locals())


def wait(command_id=None, created=None, custom=None, deleted=None, exists=None, expand=None, instance_view=None, interval=None, location=None, name=None, resource_group=None, timeout=None, updated=None, vm_name=None):
    '''
    Place the CLI in a waiting state until a condition of the res virtual-machine-run-command is met.

    Optional Parameters:
    - command_id -- The command id.
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - expand -- The expand expression to apply on the operation.
    - instance_view -- Track the run command progress
    - interval -- polling interval in seconds
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - name -- The name of the virtual machine run command.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    - vm_name -- The name of the virtual machine
    '''
    return _call_az("az vm run-command wait", locals())




from ... pyaz_utils import _call_az

def upload(package, workspace_name, no_progress=None):
    '''
    Upload a local workspace package file to an Azure Synapse workspace.

    Required Parameters:
    - package -- Specifies a local file path for a file to upload as workspace package.
    - workspace_name -- The workspace name.

    Optional Parameters:
    - no_progress -- Include this flag to disable progress reporting for the command.
    '''
    return _call_az("az synapse workspace-package upload", locals())


def upload_batch(source, workspace_name, no_progress=None):
    '''
    Upload workspace package files from a local directory to an Azure Synapse workspace.

    Required Parameters:
    - source -- The directory where the files to be uploaded are located.
    - workspace_name -- The workspace name.

    Optional Parameters:
    - no_progress -- Include this flag to disable progress reporting for the command.
    '''
    return _call_az("az synapse workspace-package upload-batch", locals())


def list(workspace_name):
    '''
    List workspace packages.

    Required Parameters:
    - workspace_name -- The workspace name.
    '''
    return _call_az("az synapse workspace-package list", locals())


def show(package_name, workspace_name):
    '''
    Get a workspace package.

    Required Parameters:
    - package_name -- The workspace package name.
    - workspace_name -- The workspace name.
    '''
    return _call_az("az synapse workspace-package show", locals())


def delete(package_name, workspace_name, no_wait=None, yes=None):
    '''
    Delete a workspace package.

    Required Parameters:
    - package_name -- The workspace package name.
    - workspace_name -- The workspace name.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az synapse workspace-package delete", locals())




'''
Manage Batch task files.
'''
from .... pyaz_utils import _call_az

def delete(file_path, job_id, task_id, account_endpoint=None, account_key=None, account_name=None, recursive=None, yes=None):
    '''
    

    Required Parameters:
    - file_path -- The path to the Task file or directory that you want to delete.
    - job_id -- The ID of the Job that contains the Task.
    - task_id -- The ID of the Task whose file you want to delete.

    Optional Parameters:
    - account_endpoint -- Batch service endpoint. Alternatively, set by environment variable: AZURE_BATCH_ENDPOINT
    - account_key -- Batch account key. Alternatively, set by environment variable: AZURE_BATCH_ACCESS_KEY
    - account_name -- Batch account name. Alternatively, set by environment variable: AZURE_BATCH_ACCOUNT
    - recursive -- Whether to delete children of a directory. If the filePath parameter represents a directory instead of a file, you can set recursive to true to delete the directory and all of the files and subdirectories in it. If recursive is false then the directory must be empty or deletion will fail.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az batch task file delete", locals())


def download(destination, file_path, job_id, task_id, account_endpoint=None, account_key=None, account_name=None, end_range=None, if_modified_since=None, if_unmodified_since=None, start_range=None):
    '''
    Download the content of a Batch task file.

    Required Parameters:
    - destination -- The path to the destination file or directory.
    - file_path -- The path to the Task file that you want to get the content of.
    - job_id -- The ID of the Job that contains the Task.
    - task_id -- The ID of the Task whose file you want to retrieve.

    Optional Parameters:
    - account_endpoint -- Batch service endpoint. Alternatively, set by environment variable: AZURE_BATCH_ENDPOINT
    - account_key -- Batch account key. Alternatively, set by environment variable: AZURE_BATCH_ACCESS_KEY
    - account_name -- Batch account name. Alternatively, set by environment variable: AZURE_BATCH_ACCOUNT
    - end_range -- The byte range to be retrieved. If not set the file will be retrieved to the end.
    - if_modified_since -- A timestamp indicating the last modified time of the resource known to the client. The operation will be performed only if the resource on the service has been modified since the specified time.
    - if_unmodified_since -- A timestamp indicating the last modified time of the resource known to the client. The operation will be performed only if the resource on the service has not been modified since the specified time.
    - start_range -- The byte range to be retrieved. If not set the file will be retrieved from the beginning.
    '''
    return _call_az("az batch task file download", locals())


def show(file_path, job_id, task_id, account_endpoint=None, account_key=None, account_name=None, if_modified_since=None, if_unmodified_since=None):
    '''
    

    Required Parameters:
    - file_path -- The path to the Task file that you want to get the properties of.
    - job_id -- The ID of the Job that contains the Task.
    - task_id -- The ID of the Task whose file you want to get the properties of.

    Optional Parameters:
    - account_endpoint -- Batch service endpoint. Alternatively, set by environment variable: AZURE_BATCH_ENDPOINT
    - account_key -- Batch account key. Alternatively, set by environment variable: AZURE_BATCH_ACCESS_KEY
    - account_name -- Batch account name. Alternatively, set by environment variable: AZURE_BATCH_ACCOUNT
    - if_modified_since -- A timestamp indicating the last modified time of the resource known to the client. The operation will be performed only if the resource on the service has been modified since the specified time.
    - if_unmodified_since -- A timestamp indicating the last modified time of the resource known to the client. The operation will be performed only if the resource on the service has not been modified since the specified time.
    '''
    return _call_az("az batch task file show", locals())


def list(job_id, task_id, account_endpoint=None, account_key=None, account_name=None, filter=None, recursive=None):
    '''
    

    Required Parameters:
    - job_id -- The ID of the Job that contains the Task.
    - task_id -- The ID of the Task whose files you want to list.

    Optional Parameters:
    - account_endpoint -- Batch service endpoint. Alternatively, set by environment variable: AZURE_BATCH_ENDPOINT
    - account_key -- Batch account key. Alternatively, set by environment variable: AZURE_BATCH_ACCESS_KEY
    - account_name -- Batch account name. Alternatively, set by environment variable: AZURE_BATCH_ACCOUNT
    - filter -- An OData $filter clause. For more information on constructing this filter, see https://docs.microsoft.com/en-us/rest/api/batchservice/odata-filters-in-batch#list-task-files.
    - recursive -- Whether to list children of the Task directory. This parameter can be used in combination with the filter parameter to list specific type of files.
    '''
    return _call_az("az batch task file list", locals())




from ..... pyaz_utils import _call_az
from . import rule_group_override


def add(policy_name, resource_group, rule_set_type, rule_set_version):
    '''
    Add a managed rule set to a CDN WAF policy.

    Required Parameters:
    - policy_name -- Name of the CDN WAF policy.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - rule_set_type -- The type of the managed rule set.
    - rule_set_version -- The version of the managed rule set.
    '''
    return _call_az("az cdn waf policy managed-rule-set add", locals())


def remove(policy_name, resource_group, rule_set_type, rule_set_version, yes=None):
    '''
    Remove a managed rule set from a CDN WAF policy.

    Required Parameters:
    - policy_name -- Name of the CDN WAF policy.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - rule_set_type -- The type of the managed rule set.
    - rule_set_version -- The version of the managed rule set.

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az cdn waf policy managed-rule-set remove", locals())


def list(policy_name, resource_group):
    '''
    List managed rule sets added to a CDN WAF policy.

    Required Parameters:
    - policy_name -- Name of the CDN WAF policy.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cdn waf policy managed-rule-set list", locals())


def show(policy_name, resource_group, rule_set_type, rule_set_version):
    '''
    Show a managed rule of a CDN WAF policy.

    Required Parameters:
    - policy_name -- Name of the CDN WAF policy.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - rule_set_type -- The type of the managed rule set.
    - rule_set_version -- The version of the managed rule set.
    '''
    return _call_az("az cdn waf policy managed-rule-set show", locals())


def list_available():
    '''
    List available CDN WAF managed rule sets.
    '''
    return _call_az("az cdn waf policy managed-rule-set list-available", locals())




'''
Get billing periods for a subscription.
'''
from ... pyaz_utils import _call_az

def list(filter=None, skiptoken=None, top=None):
    '''
    

    Optional Parameters:
    - filter -- May be used to filter billing periods by billingPeriodEndDate. The filter supports 'eq', 'lt', 'gt', 'le', 'ge', and 'and'. It does not currently support 'ne', 'or', or 'not'.
    - skiptoken -- Skiptoken is only used if a previous operation returned a partial result. If a previous response contains a nextLink element, the value of the nextLink element will include a skiptoken parameter that specifies a starting point to use for subsequent calls.
    - top -- May be used to limit the number of results to the most recent N billing periods.
    '''
    return _call_az("az billing period list", locals())


def show(name):
    '''
    

    Required Parameters:
    - name -- name of the billing period
    '''
    return _call_az("az billing period show", locals())




'''
Manage Azure Search services, admin keys and query keys.
'''
from .. pyaz_utils import _call_az
from . import admin_key, private_endpoint_connection, private_link_resource, query_key, service, shared_private_link_resource




'''
Manage Azure Media Services accounts.
'''
from ... pyaz_utils import _call_az
from . import encryption, mru, sp, storage


def show(name, resource_group=None):
    '''
    Show the details of an Azure Media Services account.

    Required Parameters:
    - name -- The name of the Azure Media Services account.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az ams account show", locals())


def delete(name, resource_group):
    '''
    Delete an Azure Media Services account.

    Required Parameters:
    - name -- The name of the Azure Media Services account.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az ams account delete", locals())


def update(name, resource_group, add=None, force_string=None, remove=None, set=None, tags=None):
    '''
    Update the details of an Azure Media Services account.

    Required Parameters:
    - name -- The name of the Azure Media Services account.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az ams account update", locals())


def list(resource_group=None):
    '''
    List Azure Media Services accounts for the entire subscription.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az ams account list", locals())


def create(name, resource_group, storage_account, location=None, mi_system_assigned=None, tags=None):
    '''
    Create an Azure Media Services account.

    Required Parameters:
    - name -- The name of the Azure Media Services account.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - storage_account -- The name or resource ID of the primary storage account to attach to the Azure Media Services account. The storage account MUST be in the same Azure subscription as the Media Services account. It is strongly recommended that the storage account be in the same resource group as the Media Services account. Blob only accounts are not allowed as primary.

    Optional Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - mi_system_assigned -- Set the system managed identity on the media services account.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az ams account create", locals())


def check_name(name, location=None):
    '''
    Checks whether the Media Service resource name is available.

    Required Parameters:
    - name -- The name of the Azure Media Services account.

    Optional Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    '''
    return _call_az("az ams account check-name", locals())




'''
Manage Synapse's role scopes.
'''
from .... pyaz_utils import _call_az

def list(workspace_name):
    '''
    List role scopes.

    Required Parameters:
    - workspace_name -- The workspace name.
    '''
    return _call_az("az synapse role scope list", locals())




from ... pyaz_utils import _call_az

def delete(name, registry_name, resource_group=None):
    '''
    Delete a private endpoint connection request for a container registry

    Required Parameters:
    - name -- The name of the private endpoint connection
    - registry_name -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az acr private-endpoint-connection delete", locals())


def show(name, registry_name, resource_group=None):
    '''
    Show details of a container registry's private endpoint connection

    Required Parameters:
    - name -- The name of the private endpoint connection
    - registry_name -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az acr private-endpoint-connection show", locals())


def list(registry_name, resource_group=None):
    '''
    List all private endpoint connections to a container registry

    Required Parameters:
    - registry_name -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az acr private-endpoint-connection list", locals())


def approve(name, registry_name, description=None, resource_group=None):
    '''
    Approve a private endpoint connection request for a container registry

    Required Parameters:
    - name -- The name of the private endpoint connection
    - registry_name -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - description -- Approval description. For example, the reason for approval.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az acr private-endpoint-connection approve", locals())


def reject(name, registry_name, description=None, resource_group=None):
    '''
    Reject a private endpoint connection request for a container registry

    Required Parameters:
    - name -- The name of the private endpoint connection
    - registry_name -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - description -- Rejection description. For example, the reason for rejection.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az acr private-endpoint-connection reject", locals())




from .... pyaz_utils import _call_az

def add(gateway_name, name, resource_group, cipher_suites=None, client_auth_configuration=None, disabled_ssl_protocols=None, min_protocol_version=None, policy_name=None, policy_type=None, trusted_client_certificates=None):
    '''
    Add ssl profiles of the application gateway.

    Required Parameters:
    - gateway_name -- Name of the application gateway.
    - name -- Name of the SSL profile that is unique within an Application Gateway.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - cipher_suites -- Ssl cipher suites to be enabled in the specified order to application gateway.
    - client_auth_configuration -- Client authentication configuration of the application gateway resource.
    - disabled_ssl_protocols -- Space-separated list of protocols to disable.
    - min_protocol_version -- Minimum version of Ssl protocol to be supported on application gateway.
    - policy_name -- Name of Ssl Policy.
    - policy_type -- Type of Ssl Policy.
    - trusted_client_certificates -- Array of references to application gateway trusted client certificates.
    '''
    return _call_az("az network application-gateway ssl-profile add", locals())


def remove(gateway_name, name, resource_group):
    '''
    Remove an existing ssl profiles of the application gateway.

    Required Parameters:
    - gateway_name -- Name of the application gateway.
    - name -- Name of the SSL profile that is unique within an Application Gateway.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network application-gateway ssl-profile remove", locals())


def list(gateway_name, resource_group):
    '''
    List the existing ssl profiles of the application gateway.

    Required Parameters:
    - gateway_name -- Name of the application gateway.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network application-gateway ssl-profile list", locals())


def show(gateway_name, name, resource_group):
    '''
    Show an existing ssl profiles of the application gateway.

    Required Parameters:
    - gateway_name -- Name of the application gateway.
    - name -- Name of the SSL profile that is unique within an Application Gateway.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network application-gateway ssl-profile show", locals())


def update(gateway_name, name, resource_group, cipher_suites=None, client_auth_configuration=None, disabled_ssl_protocols=None, min_protocol_version=None, policy_name=None, policy_type=None, trusted_client_certificates=None):
    '''
    Update ssl profiles of the application gateway.

    Required Parameters:
    - gateway_name -- Name of the application gateway.
    - name -- Name of the SSL profile that is unique within an Application Gateway.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - cipher_suites -- Ssl cipher suites to be enabled in the specified order to application gateway.
    - client_auth_configuration -- Client authentication configuration of the application gateway resource.
    - disabled_ssl_protocols -- Space-separated list of protocols to disable.
    - min_protocol_version -- Minimum version of Ssl protocol to be supported on application gateway.
    - policy_name -- Name of Ssl Policy.
    - policy_type -- Type of Ssl Policy.
    - trusted_client_certificates -- Array of references to application gateway trusted client certificates.
    '''
    return _call_az("az network application-gateway ssl-profile update", locals())




'''
Manage static apps.
'''
from .. pyaz_utils import _call_az
from . import appsettings, environment, functions, hostname, identity, secrets, users


def list(resource_group=None):
    '''
    List all static app resources in a subscription, or in resource group if provided

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az staticwebapp list", locals())


def show(name, resource_group=None):
    '''
    Show details of a static app.

    Required Parameters:
    - name -- Name of the static site

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az staticwebapp show", locals())


def create(branch, location, name, resource_group, source, api_location=None, app_location=None, login_with_github=None, no_wait=None, output_location=None, sku=None, tags=None, token=None):
    '''
    Create a static app with content from a GitHub repository URL and on the provided branch. If the repo is under a Github organization, please ensure that the Azure CLI Github App has access to the organization. Access can be requested in the browser when using the "--login-with-github" argument. Access must be granted by the organization's admin.

    Required Parameters:
    - branch -- The target branch in the repository.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - name -- Name of the static site
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - source -- URL for the repository of the static site.

    Optional Parameters:
    - api_location -- Location of your Azure Functions code. For example, '/api' represents a folder called 'api'.
    - app_location -- Location of your application code. For example, '/' represents the root of your app, while '/app' represents a directory called 'app'
    - login_with_github -- Interactively log in with Github to retrieve the Personal Access Token
    - no_wait -- Do not wait for the long-running operation to finish.
    - output_location -- The path of your build output relative to your apps location. For example, setting a value of 'build' when your app location is set to '/app' will cause the content at '/app/build' to be served.
    - sku -- The pricing tiers for Static Web App
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - token -- A user's github repository token. This is used to setup the Github Actions workflow file and API secrets. If you need to create a Github Personal Access Token, please run with the '--login-with-github' flag or follow the steps found at the following link:
https://help.github.com/en/articles/creating-a-personal-access-token-for-the-command-line
    '''
    return _call_az("az staticwebapp create", locals())


def delete(name, no_wait=None, resource_group=None, yes=None):
    '''
    Delete a static app.

    Required Parameters:
    - name -- Name of the static site

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az staticwebapp delete", locals())


def disconnect(name, no_wait=None, resource_group=None):
    '''
    Disconnect source control to enable connecting to a different repo.

    Required Parameters:
    - name -- Name of the static site

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az staticwebapp disconnect", locals())


def reconnect(branch, name, source, login_with_github=None, no_wait=None, resource_group=None, token=None):
    '''
    Connect to a repo and branch following a disconnect command.

    Required Parameters:
    - branch -- The target branch in the repository.
    - name -- Name of the static site
    - source -- URL for the repository of the static site.

    Optional Parameters:
    - login_with_github -- Interactively log in with Github to retrieve the Personal Access Token
    - no_wait -- Do not wait for the long-running operation to finish.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - token -- A user's github repository token. This is used to setup the Github Actions workflow file and API secrets. If you need to create a Github Personal Access Token, please run with the '--login-with-github' flag or follow the steps found at the following link:
https://help.github.com/en/articles/creating-a-personal-access-token-for-the-command-line
    '''
    return _call_az("az staticwebapp reconnect", locals())


def update(name, branch=None, no_wait=None, sku=None, source=None, tags=None, token=None):
    '''
    Update a static app. Return the app updated.

    Required Parameters:
    - name -- Name of the static site

    Optional Parameters:
    - branch -- The target branch in the repository.
    - no_wait -- Do not wait for the long-running operation to finish.
    - sku -- The pricing tiers for Static Web App
    - source -- URL for the repository of the static site.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - token -- A user's github repository token. This is used to setup the Github Actions workflow file and API secrets. If you need to create a Github Personal Access Token, please run with the '--login-with-github' flag or follow the steps found at the following link:
https://help.github.com/en/articles/creating-a-personal-access-token-for-the-command-line
    '''
    return _call_az("az staticwebapp update", locals())




from .... pyaz_utils import _call_az

def show(backup_id=None, database=None, location=None, managed_instance=None, name=None):
    '''
    Get a long term retention backup for a managed database.

    Optional Parameters:
    - backup_id -- The resource id of the backups. Use 'az sql midb ltr-backup show' or 'az sql midb ltr-backup list' for backup id. If provided, other arguments are not required. 
    - database -- The name of the Azure SQL Managed Database.
    - location -- The location of the desired backup(s).
    - managed_instance -- Name of the Azure SQL managed instance.
    - name -- The name of the LTR backup. Use 'az sql midb ltr-backup show' or 'az sql midb ltr-backup list' for backup name.
    '''
    return _call_az("az sql midb ltr-backup show", locals())


def list(location, database=None, database_state=None, managed_instance=None, only_latest_per_database=None, resource_group=None):
    '''
    List the long term retention backups for a location, instance or database.

    Required Parameters:
    - location -- The location of the desired backup(s).

    Optional Parameters:
    - database -- The name of the Azure SQL Managed Database. If specified (along with instance name), retrieves all requested backups under this database.
    - database_state -- 'All', 'Live', or 'Deleted'. Will fetch backups only from databases of specified state. If no state provied, defaults to 'All'.
    - managed_instance -- Name of the Azure SQL managed instance. If specified, retrieves all requested backups under this managed instance.
    - only_latest_per_database -- If true, will only return the latest backup for each database
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sql midb ltr-backup list", locals())


def delete(backup_id=None, database=None, location=None, managed_instance=None, name=None, yes=None):
    '''
    Delete a long term retention backup.

    Optional Parameters:
    - backup_id -- The resource id of the backups. Use 'az sql midb ltr-backup show' or 'az sql midb ltr-backup list' for backup id. If provided, other arguments are not required. 
    - database -- The name of the Azure SQL Managed Database.
    - location -- The location of the desired backup(s).
    - managed_instance -- Name of the Azure SQL managed instance.
    - name -- The name of the LTR backup. Use 'az sql midb ltr-backup show' or 'az sql midb ltr-backup list' for backup name.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az sql midb ltr-backup delete", locals())


def restore(backup_id, dest_database, dest_mi, dest_resource_group, no_wait=None):
    '''
    Restore a long term retention backup to a new database.

    Required Parameters:
    - backup_id -- The resource id of the long term retention backup to be restored. Use 'az sql midb ltr-backup show' or 'az sql midb ltr-backup list' for backup id.
    - dest_database -- Name of the managed database that will be created as the restore destination.
    - dest_mi -- Name of the managed instance to restore managed database to.
    - dest_resource_group -- Name of the resource group of the managed instance to restore managed database to.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az sql midb ltr-backup restore", locals())


def wait(database, managed_instance, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the managed database is met.

    Required Parameters:
    - database -- The name of the Azure SQL Managed Database.
    - managed_instance -- Name of the Azure SQL managed instance.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az sql midb ltr-backup wait", locals())




from .... pyaz_utils import _call_az

def start(name, resource_group, filter=None, no_wait=None):
    '''
    Start packet capture on a VPN connection.

    Required Parameters:
    - name -- Connection name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - filter -- Data filter.
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az network vpn-connection packet-capture start", locals())


def stop(name, resource_group, sas_url, no_wait=None):
    '''
    Stop packet capture on a VPN connection.

    Required Parameters:
    - name -- Connection name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - sas_url -- The SAS url to be used for packet capture on VPN connection.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az network vpn-connection packet-capture stop", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the vpn connection packet capture is met.

    Required Parameters:
    - name -- Connection name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az network vpn-connection packet-capture wait", locals())




'''
Manage a cluster's settings.
'''
from .... pyaz_utils import _call_az

def set(cluster_name, resource_group, parameter=None, section=None, settings_section_description=None, value=None):
    '''
    Update the settings of a cluster.

    Required Parameters:
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - parameter -- parameter name
    - section -- section name
    - settings_section_description -- JSON encoded parameters configuration. Use @{file} to load from a file. For example: [{"section": "NamingService","parameter": "MaxOperationTimeout","value": 1000},{"section": "MaxFileOperationTimeout","parameter": "Max2","value": 1000]
    - value -- Specify the value
    '''
    return _call_az("az sf cluster setting set", locals())


def remove(cluster_name, resource_group, parameter=None, section=None, settings_section_description=None):
    '''
    Remove settings from a cluster.

    Required Parameters:
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - parameter -- parameter name
    - section -- section name
    - settings_section_description -- JSON encoded parameters configuration. Use @{file} to load from a file. For example: [{"section": "NamingService","parameter": "MaxOperationTimeout"}]
    '''
    return _call_az("az sf cluster setting remove", locals())




'''
Manage links between resources.
'''
from ... pyaz_utils import _call_az

def create(link, target, notes=None):
    '''
    Create a new link between resources.

    Required Parameters:
    - link -- Fully-qualified resource ID of the resource link.
    - target -- Fully-qualified resource ID of the resource link target.

    Optional Parameters:
    - notes -- Notes for the link.
    '''
    return _call_az("az resource link create", locals())


def delete(link):
    '''
    Delete a link between resources.

    Required Parameters:
    - link -- Fully-qualified resource ID of the resource link.
    '''
    return _call_az("az resource link delete", locals())


def show(link):
    '''
    

    Required Parameters:
    - link -- Fully-qualified resource ID of the resource link.
    '''
    return _call_az("az resource link show", locals())


def list(filter=None, scope=None):
    '''
    List resource links.

    Optional Parameters:
    - filter -- Filter string for limiting results.
    - scope -- Fully-qualified scope for retrieving links.
    '''
    return _call_az("az resource link list", locals())


def update(link, notes=None, target=None):
    '''
    Update link between resources.

    Required Parameters:
    - link -- Fully-qualified resource ID of the resource link.

    Optional Parameters:
    - notes -- Notes for the link.
    - target -- Fully-qualified resource ID of the resource link target.
    '''
    return _call_az("az resource link update", locals())




'''
Manage Azure API Management services.
'''
from .. pyaz_utils import _call_az
from . import api, nv


def create(name, publisher_email, publisher_name, resource_group, enable_client_certificate=None, enable_managed_identity=None, location=None, no_wait=None, sku_capacity=None, sku_name=None, tags=None, virtual_network=None):
    '''
    Create an API Management service instance.

    Required Parameters:
    - name -- The name of the api management service instance
    - publisher_email -- The e-mail address to receive all system notifications.
    - publisher_name -- The name of your organization for use in the developer portal and e-mail notifications.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - enable_client_certificate -- Enforces a client certificate to be presented on each request to the gateway and also enables the ability to authenticate the certificate in the policy on the gateway.
    - enable_managed_identity -- Create a managed identity for the API Management service to access other Azure resources.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - no_wait -- Do not wait for the long-running operation to finish.
    - sku_capacity -- The number of deployed units of the SKU.
    - sku_name -- The sku of the api management instance
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - virtual_network -- The virtual network type.
    '''
    return _call_az("az apim create", locals())


def show(name, resource_group):
    '''
    Show details of an API Management service instance.

    Required Parameters:
    - name -- The name of the api management service instance
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az apim show", locals())


def list(resource_group=None):
    '''
    List API Management service instances.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az apim list", locals())


def delete(name, resource_group, no_wait=None, yes=None):
    '''
    Deletes an API Management service.

    Required Parameters:
    - name -- The name of the api management service instance
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az apim delete", locals())


def update(name, resource_group, add=None, enable_client_certificate=None, enable_managed_identity=None, force_string=None, no_wait=None, publisher_email=None, publisher_name=None, remove=None, set=None, sku_capacity=None, sku_name=None, tags=None, virtual_network=None):
    '''
    Update an API Management service instance.

    Required Parameters:
    - name -- The name of the api management service instance
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - enable_client_certificate -- Enforces a client certificate to be presented on each request to the gateway and also enables the ability to authenticate the certificate in the policy on the gateway.
    - enable_managed_identity -- Create a managed identity for the API Management service to access other Azure resources.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - no_wait -- Do not wait for the long-running operation to finish.
    - publisher_email -- The e-mail address to receive all system notifications.
    - publisher_name -- The name of your organization for use in the developer portal and e-mail notifications.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - sku_capacity -- The number of deployed units of the SKU.
    - sku_name -- The sku of the api management instance
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - virtual_network -- The virtual network type.
    '''
    return _call_az("az apim update", locals())


def check_name(name):
    '''
    

    Required Parameters:
    - name -- The name of the api management service instance
    '''
    return _call_az("az apim check-name", locals())


def backup(backup_name, name, resource_group, storage_account_container, storage_account_key, storage_account_name, no_wait=None):
    '''
    Creates a backup of the API Management service to the given Azure Storage Account. This is long running operation and could take several minutes to complete.

    Required Parameters:
    - backup_name -- The name of the backup file to create.
    - name -- The name of the api management service instance
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - storage_account_container -- The name of the storage account container used to place the backup.
    - storage_account_key -- The access key of the storage account used to place the backup.
    - storage_account_name -- The name of the storage account used to place the backup.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az apim backup", locals())


def restore(backup_name, name, resource_group, storage_account_container, storage_account_key, storage_account_name, no_wait=None):
    '''
    Restores a backup of an API Management service created using the ApiManagementService_Backup operation on the current service. This is a long running operation and could take several minutes to complete.

    Required Parameters:
    - backup_name -- The name of the backup file to restore.
    - name -- The name of the api management service instance
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - storage_account_container -- The name of the storage account container used to retrieve the backup from.
    - storage_account_key -- The access key of the storage account used to retrieve the backup from.
    - storage_account_name -- The name of the storage account used to retrieve the backup from.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az apim restore", locals())


def apply_network_updates(name, resource_group, location=None, no_wait=None):
    '''
    

    Required Parameters:
    - name -- The name of the api management service instance
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az apim apply-network-updates", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of an apim is met.

    Required Parameters:
    - name -- The name of the api management service instance
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az apim wait", locals())




'''
Manage Synapse's role definitions.
'''
from .... pyaz_utils import _call_az

def list(workspace_name, is_built_in=None):
    '''
    List role definitions.

    Required Parameters:
    - workspace_name -- The workspace name.

    Optional Parameters:
    - is_built_in -- Is a Synapse Built-In Role or not.
    '''
    return _call_az("az synapse role definition list", locals())


def show(role, workspace_name):
    '''
    Get role definition by role id/name.

    Required Parameters:
    - role -- The role name/id that is assigned to the principal.
    - workspace_name -- The workspace name.
    '''
    return _call_az("az synapse role definition show", locals())




'''
Manage data disks of a VMSS.
'''
from ... pyaz_utils import _call_az

def attach(resource_group, vmss_name, caching=None, disk=None, instance_id=None, lun=None, size_gb=None, sku=None):
    '''
    Attach managed data disks to a scale set or its instances.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vmss_name -- Scale set name. You can configure the default using `az configure --defaults vmss=<name>`

    Optional Parameters:
    - caching -- Disk caching policy
    - disk -- existing disk name or ID to attach or detach from VM instances
    - instance_id -- Scale set VM instance id
    - lun -- 0-based logical unit number (LUN). Max value depends on the Virtual Machine instance size.
    - size_gb -- size in GB. Max size: 4095 GB (certain preview disks can be larger).
    - sku -- Underlying storage SKU
    '''
    return _call_az("az vmss disk attach", locals())


def detach(lun, resource_group, vmss_name, instance_id=None):
    '''
    Detach managed data disks from a scale set or its instances.

    Required Parameters:
    - lun -- 0-based logical unit number (LUN). Max value depends on the Virtual Machine instance size.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vmss_name -- Scale set name. You can configure the default using `az configure --defaults vmss=<name>`

    Optional Parameters:
    - instance_id -- Scale set VM instance id
    '''
    return _call_az("az vmss disk detach", locals())




'''
Gives access to all files of a recovery point.
'''
from .... pyaz_utils import _call_az

def mount_rp(container_name, item_name, resource_group, rp_name, vault_name):
    '''
    Download a script which mounts files of a recovery point.

    Required Parameters:
    - container_name -- Name of the backup container. Accepts 'Name' or 'FriendlyName' from the output of az backup container list command. If 'FriendlyName' is passed then BackupManagementType is required.
    - item_name -- Name of the backed up item.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - rp_name -- Name of the recovery point.
    - vault_name -- Name of the Recovery services vault.
    '''
    return _call_az("az backup restore files mount-rp", locals())


def unmount_rp(container_name, item_name, resource_group, rp_name, vault_name):
    '''
    Close access to the recovery point.

    Required Parameters:
    - container_name -- Name of the backup container. Accepts 'Name' or 'FriendlyName' from the output of az backup container list command. If 'FriendlyName' is passed then BackupManagementType is required.
    - item_name -- Name of the backed up item.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - rp_name -- Name of the recovery point.
    - vault_name -- Name of the Recovery services vault.
    '''
    return _call_az("az backup restore files unmount-rp", locals())




'''
Manage tasks for a Data Migration Service instance's project.
'''
from .... pyaz_utils import _call_az

def create(database_options_json, name, project_name, resource_group, service_name, source_connection_json, target_connection_json, enable_data_integrity_validation=None, enable_query_analysis_validation=None, enable_schema_validation=None, task_type=None):
    '''
    Create and start a migration task.

    Required Parameters:
    - database_options_json -- None
    - name -- The name of the Task.
    - project_name -- The name of the Project.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_name -- The name of the Service.
    - source_connection_json -- None
    - target_connection_json -- None

    Optional Parameters:
    - enable_data_integrity_validation -- None
    - enable_query_analysis_validation -- None
    - enable_schema_validation -- None
    - task_type -- None
    '''
    return _call_az("az dms project task create", locals())


def cutover(name, object_name, project_name, resource_group, service_name):
    '''
    For an online migration task, complete the migration by performing a cutover.

    Required Parameters:
    - name -- The name of the Task.
    - object_name -- None
    - project_name -- The name of the Project.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_name -- The name of the Service.
    '''
    return _call_az("az dms project task cutover", locals())


def delete(name, project_name, resource_group, service_name, delete_running_tasks=None, yes=None):
    '''
    Delete a migration task.

    Required Parameters:
    - name -- The name of the Task.
    - project_name -- The name of the Project.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_name -- The name of the Service.

    Optional Parameters:
    - delete_running_tasks -- Delete the resource even if it contains running tasks.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az dms project task delete", locals())


def list(project_name, resource_group, service_name, task_type=None):
    '''
    List the tasks within a project. Some tasks may have a status of Unknown, which indicates that an error occurred while querying the status of that task.

    Required Parameters:
    - project_name -- The name of the Project.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_name -- The name of the Service.

    Optional Parameters:
    - task_type -- Filter tasks by task type.
    '''
    return _call_az("az dms project task list", locals())


def show(name, project_name, resource_group, service_name, expand=None):
    '''
    Show the details of a migration task. Use the "--expand" to get more details.

    Required Parameters:
    - name -- The name of the Task.
    - project_name -- The name of the Project.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_name -- The name of the Service.

    Optional Parameters:
    - expand -- Expand the response.
    '''
    return _call_az("az dms project task show", locals())


def cancel(name, project_name, resource_group, service_name):
    '''
    Cancel a task if it's currently queued or running.

    Required Parameters:
    - name -- The name of the Task.
    - project_name -- The name of the Project.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_name -- The name of the Service.
    '''
    return _call_az("az dms project task cancel", locals())


def check_name(name, project_name, resource_group, service_name):
    '''
    Check if a given task name is available within a given instance of DMS as well as the name's validity.

    Required Parameters:
    - name -- The name of the Task.
    - project_name -- The name of the Project.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_name -- The name of the Service.
    '''
    return _call_az("az dms project task check-name", locals())




'''
Manage and operate Synapse Workspace, Spark Pool, SQL Pool.
'''
from .. pyaz_utils import _call_az
from . import activity_run, data_flow, dataset, integration_runtime, integration_runtime_node, kusto_operation, linked_service, managed_private_endpoints, notebook, pipeline, pipeline_run, spark_job_definition, sql_script, trigger, trigger_run, workspace, workspace_package




'''
Manage billing instruction
'''
from ... pyaz_utils import _call_az

def list(account_name, profile_name):
    '''
    List the instructions by billing profile id.

    Required Parameters:
    - account_name -- The ID that uniquely identifies a billing account.
    - profile_name -- The ID that uniquely identifies a billing profile.
    '''
    return _call_az("az billing instruction list", locals())


def show(account_name, name, profile_name):
    '''
    Show the instruction by name. These are custom billing instructions and are only applicable for certain customers.

    Required Parameters:
    - account_name -- The ID that uniquely identifies a billing account.
    - name -- Instruction Name.
    - profile_name -- The ID that uniquely identifies a billing profile.
    '''
    return _call_az("az billing instruction show", locals())


def create(account_name, name, profile_name, amount=None, creation_date=None, end_date=None, start_date=None):
    '''
    Create an instruction. These are custom billing instructions and are only applicable for certain customers.

    Required Parameters:
    - account_name -- The ID that uniquely identifies a billing account.
    - name -- Instruction Name.
    - profile_name -- The ID that uniquely identifies a billing profile.

    Optional Parameters:
    - amount -- The amount budgeted for this billing instruction.
    - creation_date -- The date this billing instruction was created.
    - end_date -- The date this billing instruction is no longer in effect.
    - start_date -- The date this billing instruction goes into effect.
    '''
    return _call_az("az billing instruction create", locals())


def update(account_name, name, profile_name, add=None, amount=None, creation_date=None, end_date=None, force_string=None, remove=None, set=None, start_date=None):
    '''
    Update an instruction. These are custom billing instructions and are only applicable for certain customers.

    Required Parameters:
    - account_name -- The ID that uniquely identifies a billing account.
    - name -- Instruction Name.
    - profile_name -- The ID that uniquely identifies a billing profile.

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - amount -- The amount budgeted for this billing instruction.
    - creation_date -- The date this billing instruction was created.
    - end_date -- The date this billing instruction is no longer in effect.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - start_date -- The date this billing instruction goes into effect.
    '''
    return _call_az("az billing instruction update", locals())




'''
Manage a SQL Instance's keys.
'''
from .... pyaz_utils import _call_az

def create(kid, managed_instance, resource_group):
    '''
    Creates a SQL Instance key.

    Required Parameters:
    - kid -- The Azure Key Vault key identifier of the server key. An example key identifier is "https://YourVaultName.vault.azure.net/keys/YourKeyName/01234567890123456789012345678901"
    - managed_instance -- Name of the Azure SQL managed instance.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sql mi key create", locals())


def delete(kid, managed_instance, resource_group):
    '''
    Deletes a SQL Instance key.

    Required Parameters:
    - kid -- The Azure Key Vault key identifier of the server key. An example key identifier is "https://YourVaultName.vault.azure.net/keys/YourKeyName/01234567890123456789012345678901"
    - managed_instance -- Name of the Azure SQL managed instance.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sql mi key delete", locals())


def show(kid, managed_instance, resource_group):
    '''
    Shows a SQL Instance key.

    Required Parameters:
    - kid -- The Azure Key Vault key identifier of the server key. An example key identifier is "https://YourVaultName.vault.azure.net/keys/YourKeyName/01234567890123456789012345678901"
    - managed_instance -- Name of the Azure SQL managed instance.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sql mi key show", locals())


def list(managed_instance, resource_group, filter=None):
    '''
    

    Required Parameters:
    - managed_instance -- Name of the Azure SQL managed instance.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - filter -- An OData filter expression that filters elements in the collection.
    '''
    return _call_az("az sql mi key list", locals())




from .... pyaz_utils import _call_az

def list(cluster_name, name, resource_group):
    '''
    List version of a given application type.

    Required Parameters:
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - name -- Specify the application type name.
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sf application-type version list", locals())


def delete(cluster_name, name, resource_group, version):
    '''
    Delete an application type version.

    Required Parameters:
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - name -- Specify the application type name.
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`
    - version -- Specify the application type version.
    '''
    return _call_az("az sf application-type version delete", locals())


def show(cluster_name, name, resource_group, version):
    '''
    Show the properties of an application type version on an Azure Service Fabric cluster.

    Required Parameters:
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - name -- Specify the application type name.
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`
    - version -- Specify the application type version.
    '''
    return _call_az("az sf application-type version show", locals())


def create(cluster_name, name, package_url, resource_group, version):
    '''
    Create a new application type on an Azure Service Fabric cluster.

    Required Parameters:
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - name -- Specify the application type name.
    - package_url -- Specify the url of the application package sfpkg file.
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`
    - version -- Specify the application type version.
    '''
    return _call_az("az sf application-type version create", locals())




'''
Manage App Service plans.
'''
from .. pyaz_utils import _call_az
from . import ase, domain, hybrid_connection, plan, vnet_integration


def list_locations(sku, linux_workers_enabled=None):
    '''
    List regions where a plan sku is available.

    Required Parameters:
    - sku -- The pricing tiers, e.g., F1(Free), D1(Shared), B1(Basic Small), B2(Basic Medium), B3(Basic Large), S1(Standard Small), P1V2(Premium V2 Small), P1V3(Premium V3 Small), P2V3(Premium V3 Medium), P3V3(Premium V3 Large), PC2 (Premium Container Small), PC3 (Premium Container Medium), PC4 (Premium Container Large), I1 (Isolated Small), I2 (Isolated Medium), I3 (Isolated Large), I1v2 (Isolated V2 Small), I2v2 (Isolated V2 Medium), I3v2 (Isolated V2 Large)

    Optional Parameters:
    - linux_workers_enabled -- get regions which support hosting web apps on Linux workers
    '''
    return _call_az("az appservice list-locations", locals())




from .... pyaz_utils import _call_az

def create(account_name, name, subnet, resource_group=None, vnet_name=None):
    '''
    Creates a virtual network rule in a Data Lake Store account.

    Required Parameters:
    - account_name -- Name of the Data Lake Store account.
    - name -- The virtual network rule name
    - subnet -- Name or ID of the subnet that allows access to DLS. If subnet name is provided, --name must be provided.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vnet_name -- The virtual network rule name
    '''
    return _call_az("az dls account network-rule create", locals())


def update(account_name, name, subnet, add=None, force_string=None, remove=None, resource_group=None, set=None, vnet_name=None):
    '''
    Updates a virtual network rule in a Data Lake Store account.

    Required Parameters:
    - account_name -- Name of the Data Lake Store account.
    - name -- The virtual network rule name
    - subnet -- Name or ID of the subnet that allows access to DLS. If subnet name is provided, --name must be provided.

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - vnet_name -- The virtual network rule name
    '''
    return _call_az("az dls account network-rule update", locals())


def list(account_name, resource_group=None):
    '''
    Lists virtual network rules in a Data Lake Store account.

    Required Parameters:
    - account_name -- Name of the Data Lake Store account.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az dls account network-rule list", locals())


def show(account_name, name, resource_group=None):
    '''
    Get the details of a virtual network rule in a Data Lake Store account.

    Required Parameters:
    - account_name -- Name of the Data Lake Store account.
    - name -- The virtual network rule name

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az dls account network-rule show", locals())


def delete(account_name, name, resource_group=None):
    '''
    Deletes a virtual network rule in a Data Lake Store account.

    Required Parameters:
    - account_name -- Name of the Data Lake Store account.
    - name -- The virtual network rule name

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az dls account network-rule delete", locals())




'''
Manage your security posture with Azure Security Center.
'''
from .. pyaz_utils import _call_az
from . import adaptive_application_controls, adaptive_network_hardenings, alert, allowed_connections, assessment, assessment_metadata, auto_provisioning_setting, contact, discovered_security_solution, external_security_solution, iot_alerts, iot_analytics, iot_recommendations, iot_solution, jit_policy, location, pricing, regulatory_compliance_assessments, regulatory_compliance_controls, regulatory_compliance_standards, secure_score_control_definitions, secure_score_controls, secure_scores, setting, sub_assessment, task, topology, workspace_setting




'''
Manage Data Lake Store filesystem access and permissions.
'''
from .... pyaz_utils import _call_az

def set_permission(account, path, permission):
    '''
    Set the permissions for a file or folder in a Data Lake Store account.

    Required Parameters:
    - account -- Name of the Data Lake Store account.
    - path -- The path in the specified Data Lake Store account where the action should take place. In the format '/folder/file.txt', where the first '/' after the DNS indicates the root of the file system.
    - permission -- The octal representation of the permissions for user, group and mask (for example: 777 is full rwx for all entities)
    '''
    return _call_az("az dls fs access set-permission", locals())


def set_owner(account, path, group=None, owner=None):
    '''
    Set the owner information for a file or folder in a Data Lake Store account.

    Required Parameters:
    - account -- Name of the Data Lake Store account.
    - path -- The path in the specified Data Lake Store account where the action should take place. In the format '/folder/file.txt', where the first '/' after the DNS indicates the root of the file system.

    Optional Parameters:
    - group -- None
    - owner -- None
    '''
    return _call_az("az dls fs access set-owner", locals())


def show(account, path):
    '''
    Display the access control list (ACL).

    Required Parameters:
    - account -- Name of the Data Lake Store account.
    - path -- The path in the specified Data Lake Store account where the action should take place. In the format '/folder/file.txt', where the first '/' after the DNS indicates the root of the file system.
    '''
    return _call_az("az dls fs access show", locals())


def set_entry(account, acl_spec, path):
    '''
    Update the access control list for a file or folder.

    Required Parameters:
    - account -- Name of the Data Lake Store account.
    - acl_spec --  The ACL specification to set on the path in the format '[default:]user|group|other:[entity id or UPN]:r|-w|-x|-,[default:]user|group|other:[entity id or UPN]:r|-w|-x|-,...'.
    - path -- The path in the specified Data Lake Store account where the action should take place. In the format '/folder/file.txt', where the first '/' after the DNS indicates the root of the file system.
    '''
    return _call_az("az dls fs access set-entry", locals())


def set(account, acl_spec, path):
    '''
    Replace the existing access control list for a file or folder.

    Required Parameters:
    - account -- Name of the Data Lake Store account.
    - acl_spec --  The ACL specification to set on the path in the format '[default:]user|group|other:[entity id or UPN]:r|-w|-x|-,[default:]user|group|other:[entity id or UPN]:r|-w|-x|-,...'.
    - path -- The path in the specified Data Lake Store account where the action should take place. In the format '/folder/file.txt', where the first '/' after the DNS indicates the root of the file system.
    '''
    return _call_az("az dls fs access set", locals())


def remove_entry(account, acl_spec, path):
    '''
    Remove entries for the access control list of a file or folder.

    Required Parameters:
    - account -- Name of the Data Lake Store account.
    - acl_spec --  The ACL specification to set on the path in the format '[default:]user|group|other:[entity id or UPN]:r|-w|-x|-,[default:]user|group|other:[entity id or UPN]:r|-w|-x|-,...'.
    - path -- The path in the specified Data Lake Store account where the action should take place. In the format '/folder/file.txt', where the first '/' after the DNS indicates the root of the file system.
    '''
    return _call_az("az dls fs access remove-entry", locals())


def remove_all(account, path, default_acl=None):
    '''
    Remove the access control list for a file or folder.

    Required Parameters:
    - account -- Name of the Data Lake Store account.
    - path -- The path in the specified Data Lake Store account where the action should take place. In the format '/folder/file.txt', where the first '/' after the DNS indicates the root of the file system.

    Optional Parameters:
    - default_acl -- A switch that, if specified, indicates that the remove ACL operation should remove the default ACL of the folder. Otherwise the regular ACL is removed.
    '''
    return _call_az("az dls fs access remove-all", locals())




'''
Manage a static web app's managed identity
'''
from ... pyaz_utils import _call_az

def assign(name, resource_group, identities=None, role=None, scope=None):
    '''
    assign managed identity to the static web app

    Required Parameters:
    - name -- Name of the static site
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - identities -- Space-separated identities to assign. Use '[system]' to refer to the system assigned identity. Default: '[system]'
    - role -- Role name or id the managed identity will be assigned
    - scope -- The scope the managed identity has access to
    '''
    return _call_az("az staticwebapp identity assign", locals())


def remove(name, resource_group, identities=None, yes=None):
    '''
    Disable static web app's managed identity

    Required Parameters:
    - name -- Name of the static site
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - identities -- Space-separated identities to assign. Use '[system]' to refer to the system assigned identity. Default: '[system]'
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az staticwebapp identity remove", locals())


def show(name, resource_group):
    '''
    display static web app's managed identity

    Required Parameters:
    - name -- Name of the static site
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az staticwebapp identity show", locals())




from ... pyaz_utils import _call_az

def approve(description=None, hsm_name=None, id=None, name=None, no_wait=None, resource_group=None, vault_name=None):
    '''
    Approve a private endpoint connection request for a Key Vault/HSM.

    Optional Parameters:
    - description -- Comments for the approve operation.
    - hsm_name -- Name of the HSM. Required if --id is not specified.(--hsm-name and --vault-name are mutually exclusive, please specify just one of them)
    - id -- The ID of the private endpoint connection associated with the Key Vault/HSM. If specified --vault-name/--hsm-name and --name/-n, this should be omitted.
    - name -- The name of the private endpoint connection associated with the Key Vault/HSM. Required if --id is not specified
    - no_wait -- Do not wait for the long-running operation to finish.
    - resource_group -- Proceed only if Key Vault belongs to the specified resource group.
    - vault_name -- Name of the Key Vault. Required if --id is not specified
    '''
    return _call_az("az keyvault private-endpoint-connection approve", locals())


def reject(description=None, hsm_name=None, id=None, name=None, no_wait=None, resource_group=None, vault_name=None):
    '''
    Reject a private endpoint connection request for a Key Vault/HSM.

    Optional Parameters:
    - description -- Comments for the reject operation.
    - hsm_name -- Name of the HSM. Required if --id is not specified.(--hsm-name and --vault-name are mutually exclusive, please specify just one of them)
    - id -- The ID of the private endpoint connection associated with the Key Vault/HSM. If specified --vault-name/--hsm-name and --name/-n, this should be omitted.
    - name -- The name of the private endpoint connection associated with the Key Vault/HSM. Required if --id is not specified
    - no_wait -- Do not wait for the long-running operation to finish.
    - resource_group -- Proceed only if Key Vault belongs to the specified resource group.
    - vault_name -- Name of the Key Vault. Required if --id is not specified
    '''
    return _call_az("az keyvault private-endpoint-connection reject", locals())


def delete(hsm_name=None, id=None, name=None, no_wait=None, resource_group=None, vault_name=None):
    '''
    Delete the specified private endpoint connection associated with a Key Vault/HSM.

    Optional Parameters:
    - hsm_name -- Name of the HSM. Required if --id is not specified.(--hsm-name and --vault-name are mutually exclusive, please specify just one of them)
    - id -- The ID of the private endpoint connection associated with the Key Vault/HSM. If specified --vault-name/--hsm-name and --name/-n, this should be omitted.
    - name -- The name of the private endpoint connection associated with the Key Vault/HSM. Required if --id is not specified
    - no_wait -- Do not wait for the long-running operation to finish.
    - resource_group -- Proceed only if Key Vault belongs to the specified resource group.
    - vault_name -- Name of the Key Vault. Required if --id is not specified
    '''
    return _call_az("az keyvault private-endpoint-connection delete", locals())


def list(hsm_name, resource_group=None):
    '''
    List all private endpoint connections associated with a HSM.

    Required Parameters:
    - hsm_name -- Name of the HSM.

    Optional Parameters:
    - resource_group -- Proceed only if Key Vault belongs to the specified resource group.
    '''
    return _call_az("az keyvault private-endpoint-connection list", locals())


def show(hsm_name=None, id=None, name=None, resource_group=None, vault_name=None):
    '''
    Show details of a private endpoint connection associated with a Key Vault/HSM.

    Optional Parameters:
    - hsm_name -- Name of the HSM. Required if --id is not specified.(--hsm-name and --vault-name are mutually exclusive, please specify just one of them)
    - id -- The ID of the private endpoint connection associated with the Key Vault/HSM. If specified --vault-name/--hsm-name and --name/-n, this should be omitted.
    - name -- The name of the private endpoint connection associated with the Key Vault/HSM. Required if --id is not specified
    - resource_group -- Proceed only if Key Vault belongs to the specified resource group.
    - vault_name -- Name of the Key Vault. Required if --id is not specified
    '''
    return _call_az("az keyvault private-endpoint-connection show", locals())


def wait(created=None, custom=None, deleted=None, exists=None, hsm_name=None, id=None, interval=None, name=None, resource_group=None, timeout=None, updated=None, vault_name=None):
    '''
    Place the CLI in a waiting state until a condition of the private endpoint connection is met.

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - hsm_name -- Name of the HSM. Required if --id is not specified.(--hsm-name and --vault-name are mutually exclusive, please specify just one of them)
    - id -- The ID of the private endpoint connection associated with the Key Vault/HSM. If specified --vault-name/--hsm-name and --name/-n, this should be omitted.
    - interval -- polling interval in seconds
    - name -- The name of the private endpoint connection associated with the Key Vault/HSM. Required if --id is not specified
    - resource_group -- Proceed only if Key Vault belongs to the specified resource group.
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    - vault_name -- Name of the Key Vault. Required if --id is not specified
    '''
    return _call_az("az keyvault private-endpoint-connection wait", locals())




'''
Manage managed identity settings.
'''
from ... pyaz_utils import _call_az

def assign(identity, name, resource_group):
    '''
    Assign managed identity for SignalR Service.

    Required Parameters:
    - identity -- Assigns managed identities to the service. Use '[system]' to refer to the system-assigned identity or a resource ID to refer to a user-assigned identity. You can only assign either on of them.
    - name -- Name of signalr service.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az signalr identity assign", locals())


def remove(name, resource_group):
    '''
    Remove managed identity for SignalR Service.

    Required Parameters:
    - name -- Name of signalr service.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az signalr identity remove", locals())


def show(name, resource_group):
    '''
    Show managed identity for SignalR Service.

    Required Parameters:
    - name -- Name of signalr service.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az signalr identity show", locals())




'''
Manage webapp authentication and authorization. To use v2 auth commands, run "az extension add --name authV2" to add the authV2 CLI extension.
'''
from ... pyaz_utils import _call_az

def show(name, resource_group, slot=None):
    '''
    Show the authentification settings for the webapp.

    Required Parameters:
    - name -- name of the web app. If left unspecified, a name will be randomly generated. You can configure the default using `az configure --defaults web=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az webapp auth show", locals())


def update(name, resource_group, aad_allowed_token_audiences=None, aad_client_id=None, aad_client_secret=None, aad_client_secret_certificate_thumbprint=None, aad_token_issuer_url=None, action=None, allowed_external_redirect_urls=None, enabled=None, facebook_app_id=None, facebook_app_secret=None, facebook_oauth_scopes=None, google_client_id=None, google_client_secret=None, google_oauth_scopes=None, microsoft_account_client_id=None, microsoft_account_client_secret=None, microsoft_account_oauth_scopes=None, runtime_version=None, slot=None, token_refresh_extension_hours=None, token_store=None, twitter_consumer_key=None, twitter_consumer_secret=None):
    '''
    Update the authentication settings for the webapp.

    Required Parameters:
    - name -- name of the web app. If left unspecified, a name will be randomly generated. You can configure the default using `az configure --defaults web=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - aad_allowed_token_audiences -- One or more token audiences (space-delimited).
    - aad_client_id -- Application ID to integrate AAD organization account Sign-in into your web app
    - aad_client_secret -- AAD application secret
    - aad_client_secret_certificate_thumbprint -- Alternative to AAD Client Secret, thumbprint of a certificate used for signing purposes
    - aad_token_issuer_url -- This url can be found in the JSON output returned from your active directory endpoint using your tenantID. The endpoint can be queried from `az cloud show` at "endpoints.activeDirectory". The tenantID can be found using `az account show`. Get the "issuer" from the JSON at <active directory endpoint>/<tenantId>/.well-known/openid-configuration.
    - action -- None
    - allowed_external_redirect_urls -- One or more urls (space-delimited).
    - enabled -- None
    - facebook_app_id -- Application ID to integrate Facebook Sign-in into your web app
    - facebook_app_secret -- Facebook Application client secret
    - facebook_oauth_scopes -- One or more facebook authentication scopes (space-delimited).
    - google_client_id -- Application ID to integrate Google Sign-in into your web app
    - google_client_secret -- Google Application client secret
    - google_oauth_scopes -- One or more Google authentication scopes (space-delimited).
    - microsoft_account_client_id -- AAD V2 Application ID to integrate Microsoft account Sign-in into your web app
    - microsoft_account_client_secret -- AAD V2 Application client secret
    - microsoft_account_oauth_scopes -- One or more Microsoft authentification scopes (space-delimited).
    - runtime_version -- Runtime version of the Authentication/Authorization feature in use for the current app
    - slot -- the name of the slot. Default to the productions slot if not specified
    - token_refresh_extension_hours -- Hours, must be formattable into a float
    - token_store -- use App Service Token Store
    - twitter_consumer_key -- Application ID to integrate Twitter Sign-in into your web app
    - twitter_consumer_secret -- Twitter Application client secret
    '''
    return _call_az("az webapp auth update", locals())




'''
Manage users of the static app.
'''
from ... pyaz_utils import _call_az

def list(name, authentication_provider=None, resource_group=None):
    '''
    Lists users and assigned roles, limited to users who accepted their invites.

    Required Parameters:
    - name -- Name of the static site

    Optional Parameters:
    - authentication_provider -- Authentication provider of the user identity such as AAD, Facebook, GitHub, Google, Twitter.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az staticwebapp users list", locals())


def invite(authentication_provider, domain, invitation_expiration_in_hours, name, roles, user_details, resource_group=None):
    '''
    Create invitation link for specified user to the static app.

    Required Parameters:
    - authentication_provider -- Authentication provider of the user identity such as AAD, Facebook, GitHub, Google, Twitter.
    - domain -- A domain added to the static app in quotes.
    - invitation_expiration_in_hours -- This value sets when the link will expire in hours. The maximum is 168 (7 days).
    - name -- Name of the static site
    - roles -- Comma-separated default or user-defined role names. Roles that can be assigned to a user are comma separated and case-insensitive (at most 50 roles up to 25 characters each and restricted to 0-9,A-Z,a-z, and _). Define roles in routes.json during root directory of your GitHub repo.
    - user_details -- Email for AAD, Facebook, and Google. Account name (handle) for GitHub and Twitter.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az staticwebapp users invite", locals())


def update(name, roles, authentication_provider=None, resource_group=None, user_details=None, user_id=None):
    '''
    Updates a user entry with the listed roles. Either user details or user id is required.

    Required Parameters:
    - name -- Name of the static site
    - roles -- Comma-separated default or user-defined role names. Roles that can be assigned to a user are comma separated and case-insensitive (at most 50 roles up to 25 characters each and restricted to 0-9,A-Z,a-z, and _). Define roles in routes.json during root directory of your GitHub repo.

    Optional Parameters:
    - authentication_provider -- Authentication provider of the user identity such as AAD, Facebook, GitHub, Google, Twitter.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - user_details -- Email for AAD, Facebook, and Google. Account name (handle) for GitHub and Twitter.
    - user_id -- Given id of registered user.
    '''
    return _call_az("az staticwebapp users update", locals())




'''
Manage tokens for an Azure Container Registry.
'''
from ... pyaz_utils import _call_az
from . import credential


def create(name, registry, expiration=None, expiration_in_days=None, gateway=None, no_passwords=None, repository=None, resource_group=None, scope_map=None, status=None):
    '''
    Create a token associated with a scope map for an Azure Container Registry.

    Required Parameters:
    - name -- The name of the token.
    - registry -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - expiration -- UTC time for which the credentials will be valid. In the format of %Y-%m-%dT%H:%M:%SZ, e.g. 2025-12-31T12:59:59Z
    - expiration_in_days -- Number of days for which the credentials will be valid. If not specified, the expiration will default to the max value "9999-12-31T23:59:59.999999+00:00"
    - gateway -- gateway permissions. Use the format "--gateway GATEWAY [ACTION1 ACTION2 ...]" per flag. Valid actions are {'config/read', 'message/write', 'config/write', 'message/read'}
    - no_passwords -- Do not generate passwords, instead use "az acr token credential generate"
    - repository -- repository permissions. Use the format "--repository REPO [ACTION1 ACTION2 ...]" per flag. Valid actions are {'content/read', 'content/write', 'metadata/write', 'metadata/read', 'content/delete'}
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - scope_map -- The name of the scope map with pre-configured repository permissions. Use "--repository" and/or "--gateway" if you would like CLI to configure one for you
    - status -- The status of the token
    '''
    return _call_az("az acr token create", locals())


def delete(name, registry, resource_group=None, yes=None):
    '''
    Delete a token for an Azure Container Registry.

    Required Parameters:
    - name -- The name of the token.
    - registry -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az acr token delete", locals())


def update(name, registry, resource_group=None, scope_map=None, status=None):
    '''
    Update a token (replace associated scope map) for an Azure Container Registry.

    Required Parameters:
    - name -- The name of the token.
    - registry -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - scope_map -- The name of the scope map associated with the token. If not specified, running this command will disassociate the current scope map related to the token.
    - status -- The status of the token
    '''
    return _call_az("az acr token update", locals())


def show(name, registry, resource_group=None):
    '''
    Show details and attributes of a token for an Azure Container Registry.

    Required Parameters:
    - name -- The name of the token.
    - registry -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az acr token show", locals())


def list(registry, resource_group=None):
    '''
    List all tokens for an Azure Container Registry.

    Required Parameters:
    - registry -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az acr token list", locals())




'''
Manage Synapse's notebooks.
'''
from ... pyaz_utils import _call_az

def create(file, name, workspace_name, executor_count=None, executor_size=None, folder_path=None, no_wait=None, spark_pool_name=None):
    '''
    Create a notebook.

    Required Parameters:
    - file -- Properties may be supplied from a JSON file using the `@{path}` syntax or a JSON string.
    - name -- The notebook name.
    - workspace_name -- The workspace name.

    Optional Parameters:
    - executor_count -- Number of executors to be allocated in the specified Spark pool for the job.
    - executor_size -- Number of core and memory to be used for executors allocated in the specified Spark pool for the job.
    - folder_path -- The folder that this notebook is in. If not specified, this notebook will appear at the root level. Eg: folder/subfolder1
    - no_wait -- Do not wait for the long-running operation to finish.
    - spark_pool_name -- The name of the Spark pool.
    '''
    return _call_az("az synapse notebook create", locals())


def set(file, name, workspace_name, executor_count=None, executor_size=None, folder_path=None, no_wait=None, spark_pool_name=None):
    '''
    Set an exist notebook.

    Required Parameters:
    - file -- Properties may be supplied from a JSON file using the `@{path}` syntax or a JSON string.
    - name -- The notebook name.
    - workspace_name -- The workspace name.

    Optional Parameters:
    - executor_count -- Number of executors to be allocated in the specified Spark pool for the job.
    - executor_size -- Number of core and memory to be used for executors allocated in the specified Spark pool for the job.
    - folder_path -- The folder that this notebook is in. If not specified, this notebook will appear at the root level. Eg: folder/subfolder1
    - no_wait -- Do not wait for the long-running operation to finish.
    - spark_pool_name -- The name of the Spark pool.
    '''
    return _call_az("az synapse notebook set", locals())


def import_(file, name, workspace_name, executor_count=None, executor_size=None, folder_path=None, no_wait=None, spark_pool_name=None):
    '''
    Import a notebook.

    Required Parameters:
    - file -- Properties may be supplied from a JSON file using the `@{path}` syntax or a JSON string.
    - name -- The notebook name.
    - workspace_name -- The workspace name.

    Optional Parameters:
    - executor_count -- Number of executors to be allocated in the specified Spark pool for the job.
    - executor_size -- Number of core and memory to be used for executors allocated in the specified Spark pool for the job.
    - folder_path -- The folder that this notebook is in. If not specified, this notebook will appear at the root level. Eg: folder/subfolder1
    - no_wait -- Do not wait for the long-running operation to finish.
    - spark_pool_name -- The name of the Spark pool.
    '''
    return _call_az("az synapse notebook import", locals())


def list(workspace_name):
    '''
    List notebooks.

    Required Parameters:
    - workspace_name -- The workspace name.
    '''
    return _call_az("az synapse notebook list", locals())


def show(name, workspace_name):
    '''
    Get a notebook.

    Required Parameters:
    - name -- The notebook name.
    - workspace_name -- The workspace name.
    '''
    return _call_az("az synapse notebook show", locals())


def export(output_folder, workspace_name, name=None):
    '''
    Export notebooks.

    Required Parameters:
    - output_folder -- The folder where the notebook should be placed.
    - workspace_name -- The workspace name.

    Optional Parameters:
    - name -- The notebook name.
    '''
    return _call_az("az synapse notebook export", locals())


def delete(name, workspace_name, no_wait=None, yes=None):
    '''
    Delete a notebook.

    Required Parameters:
    - name -- The notebook name.
    - workspace_name -- The workspace name.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az synapse notebook delete", locals())




'''
Manage role assignments.
'''
from ... pyaz_utils import _call_az

def delete(assignee=None, ids=None, include_inherited=None, resource_group=None, role=None, scope=None, yes=None):
    '''
    Delete role assignments.

    Optional Parameters:
    - assignee -- represent a user, group, or service principal. supported format: object id, user sign-in name, or service principal name
    - ids -- space-separated role assignment ids
    - include_inherited -- include assignments applied on parent scopes
    - resource_group -- use it only if the role or assignment was added at the level of a resource group
    - role -- role name or id
    - scope -- scope at which the role assignment or definition applies to, e.g., /subscriptions/0b1f6471-1bf0-4dda-aec3-111122223333, /subscriptions/0b1f6471-1bf0-4dda-aec3-111122223333/resourceGroups/myGroup, or /subscriptions/0b1f6471-1bf0-4dda-aec3-111122223333/resourceGroups/myGroup/providers/Microsoft.Compute/virtualMachines/myVM
    - yes -- Continue to delete all assignments under the subscription
    '''
    return _call_az("az role assignment delete", locals())


def list(all=None, assignee=None, include_classic_administrators=None, include_groups=None, include_inherited=None, resource_group=None, role=None, scope=None):
    '''
    List role assignments.

    Optional Parameters:
    - all -- show all assignments under the current subscription
    - assignee -- represent a user, group, or service principal. supported format: object id, user sign-in name, or service principal name
    - include_classic_administrators -- list default role assignments for subscription classic administrators, aka co-admins
    - include_groups -- include extra assignments to the groups of which the user is a member(transitively).
    - include_inherited -- include assignments applied on parent scopes
    - resource_group -- use it only if the role or assignment was added at the level of a resource group
    - role -- role name or id
    - scope -- scope at which the role assignment or definition applies to, e.g., /subscriptions/0b1f6471-1bf0-4dda-aec3-111122223333, /subscriptions/0b1f6471-1bf0-4dda-aec3-111122223333/resourceGroups/myGroup, or /subscriptions/0b1f6471-1bf0-4dda-aec3-111122223333/resourceGroups/myGroup/providers/Microsoft.Compute/virtualMachines/myVM
    '''
    return _call_az("az role assignment list", locals())


def create(role, assignee=None, assignee_object_id=None, assignee_principal_type=None, condition=None, condition_version=None, description=None, resource_group=None, scope=None):
    '''
    Create a new role assignment for a user, group, or service principal.

    Required Parameters:
    - role -- role name or id

    Optional Parameters:
    - assignee -- represent a user, group, or service principal. supported format: object id, user sign-in name, or service principal name
    - assignee_object_id -- Use this parameter instead of '--assignee' to bypass Graph API invocation in case of insufficient privileges. This parameter only works with object ids for users, groups, service principals, and managed identities. For managed identities use the principal id. For service principals, use the object id and not the app id.
    - assignee_principal_type -- use with --assignee-object-id to avoid errors caused by propagation latency in AAD Graph
    - condition -- Condition under which the user can be granted permission.
    - condition_version -- Version of the condition syntax. If --condition is specified without --condition-version, default to 2.0.
    - description -- Description of role assignment.
    - resource_group -- use it only if the role or assignment was added at the level of a resource group
    - scope -- scope at which the role assignment or definition applies to, e.g., /subscriptions/0b1f6471-1bf0-4dda-aec3-111122223333, /subscriptions/0b1f6471-1bf0-4dda-aec3-111122223333/resourceGroups/myGroup, or /subscriptions/0b1f6471-1bf0-4dda-aec3-111122223333/resourceGroups/myGroup/providers/Microsoft.Compute/virtualMachines/myVM
    '''
    return _call_az("az role assignment create", locals())


def update(role_assignment):
    '''
    Update an existing role assignment for a user, group, or service principal.

    Required Parameters:
    - role_assignment -- Description of an existing role assignment as JSON, or a path to a file containing a JSON description.
    '''
    return _call_az("az role assignment update", locals())


def list_changelogs(end_time=None, start_time=None):
    '''
    List changelogs for role assignments.

    Optional Parameters:
    - end_time -- The end time of the query in the format of %Y-%m-%dT%H:%M:%SZ, e.g. 2000-12-31T12:59:59Z. Defaults to the current time
    - start_time -- The start time of the query in the format of %Y-%m-%dT%H:%M:%SZ, e.g. 2000-12-31T12:59:59Z. Defaults to 1 Hour prior to the current time
    '''
    return _call_az("az role assignment list-changelogs", locals())




from ... pyaz_utils import _call_az

def show(endpoint_name, name, profile_name, resource_group):
    '''
    

    Required Parameters:
    - endpoint_name -- Name of the CDN endpoint.
    - name -- Name of the origin group.
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cdn origin-group show", locals())


def list(endpoint_name, profile_name, resource_group):
    '''
    

    Required Parameters:
    - endpoint_name -- Name of the CDN endpoint.
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cdn origin-group list", locals())


def create(endpoint_name, name, profile_name, resource_group, origins=None, probe_interval=None, probe_method=None, probe_path=None, probe_protocol=None):
    '''
    Create an origin group.

    Required Parameters:
    - endpoint_name -- Name of the CDN endpoint.
    - name -- Name of the origin group.
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - origins -- None
    - probe_interval -- None
    - probe_method -- None
    - probe_path -- None
    - probe_protocol -- None
    '''
    return _call_az("az cdn origin-group create", locals())


def update(endpoint_name, name, profile_name, resource_group, origins=None, probe_interval=None, probe_method=None, probe_path=None, probe_protocol=None):
    '''
    Update an origin group.

    Required Parameters:
    - endpoint_name -- Name of the CDN endpoint.
    - name -- Name of the origin group.
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - origins -- None
    - probe_interval -- None
    - probe_method -- None
    - probe_path -- None
    - probe_protocol -- None
    '''
    return _call_az("az cdn origin-group update", locals())


def delete(endpoint_name, name, profile_name, resource_group, yes=None):
    '''
    

    Required Parameters:
    - endpoint_name -- Name of the CDN endpoint.
    - name -- Name of the origin group.
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az cdn origin-group delete", locals())




from ... pyaz_utils import _call_az

def add(name, ip_address=None, no_wait=None, resource_group=None, subnet=None, vnet_name=None):
    '''
    

    Required Parameters:
    - name -- Name of the Vault.

    Optional Parameters:
    - ip_address -- IPv4 address or CIDR range. Can supply a list: --ip-address ip1 [ip2]...
    - no_wait -- Do not wait for the long-running operation to finish.
    - resource_group -- Proceed only if Key Vault belongs to the specified resource group.
    - subnet -- Name or ID of subnet. If name is supplied, `--vnet-name` must be supplied.
    - vnet_name -- Name of a virtual network.
    '''
    return _call_az("az keyvault network-rule add", locals())


def remove(name, ip_address=None, no_wait=None, resource_group=None, subnet=None, vnet_name=None):
    '''
    

    Required Parameters:
    - name -- Name of the Vault.

    Optional Parameters:
    - ip_address -- IPv4 address or CIDR range.
    - no_wait -- Do not wait for the long-running operation to finish.
    - resource_group -- Proceed only if Key Vault belongs to the specified resource group.
    - subnet -- Name or ID of subnet. If name is supplied, `--vnet-name` must be supplied.
    - vnet_name -- Name of a virtual network.
    '''
    return _call_az("az keyvault network-rule remove", locals())


def list(name, resource_group=None):
    '''
    

    Required Parameters:
    - name -- Name of the Vault.

    Optional Parameters:
    - resource_group -- Proceed only if Key Vault belongs to the specified resource group.
    '''
    return _call_az("az keyvault network-rule list", locals())


def wait(name, created=None, custom=None, deleted=None, exists=None, interval=None, resource_group=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the vault is met.

    Required Parameters:
    - name -- Name of the Vault.

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - resource_group -- Proceed only if Key Vault belongs to the specified resource group.
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az keyvault network-rule wait", locals())




from ... pyaz_utils import _call_az

def list():
    '''
    List the auto provisioning settings.
    '''
    return _call_az("az security auto-provisioning-setting list", locals())


def show(name):
    '''
    Shows an auto provisioning setting.

    Required Parameters:
    - name -- name of the resource to be fetched
    '''
    return _call_az("az security auto-provisioning-setting show", locals())


def update(auto_provision, name):
    '''
    Updates your automatic provisioning settings on the subscription.

    Required Parameters:
    - auto_provision -- Automatic provisioning toggle. possible values are "On" or "Off"
    - name -- name of the resource to be fetched
    '''
    return _call_az("az security auto-provisioning-setting update", locals())




'''
View all Adaptive Network Hardening resources
'''
from ... pyaz_utils import _call_az

def show(adaptive_network_hardenings_resource_name, resource_group, resource_name, resource_namespace, resource_type):
    '''
    Gets a single Adaptive Network Hardening resource.

    Required Parameters:
    - adaptive_network_hardenings_resource_name -- Adaptive Network Hardening resource name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - resource_name -- Name of the resource
    - resource_namespace -- The Namespace of the resource
    - resource_type -- The type of the resource
    '''
    return _call_az("az security adaptive_network_hardenings show", locals())


def list(resource_group, resource_name, resource_namespace, resource_type):
    '''
    Gets a list of Adaptive Network Hardenings resources in scope of an extended resource.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - resource_name -- Name of the resource
    - resource_namespace -- The Namespace of the resource
    - resource_type -- The type of the resource
    '''
    return _call_az("az security adaptive_network_hardenings list", locals())




'''
Manage automatic scaling of Batch pools.
'''
from .... pyaz_utils import _call_az

def disable(pool_id, account_endpoint=None, account_key=None, account_name=None):
    '''
    

    Required Parameters:
    - pool_id -- The ID of the Pool on which to disable automatic scaling.

    Optional Parameters:
    - account_endpoint -- Batch service endpoint. Alternatively, set by environment variable: AZURE_BATCH_ENDPOINT
    - account_key -- Batch account key. Alternatively, set by environment variable: AZURE_BATCH_ACCESS_KEY
    - account_name -- Batch account name. Alternatively, set by environment variable: AZURE_BATCH_ACCOUNT
    '''
    return _call_az("az batch pool autoscale disable", locals())


def enable(pool_id, account_endpoint=None, account_key=None, account_name=None, auto_scale_evaluation_interval=None, auto_scale_formula=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None):
    '''
    

    Required Parameters:
    - pool_id -- The ID of the Pool on which to enable automatic scaling.

    Optional Parameters:
    - account_endpoint -- Batch service endpoint. Alternatively, set by environment variable: AZURE_BATCH_ENDPOINT
    - account_key -- Batch account key. Alternatively, set by environment variable: AZURE_BATCH_ACCESS_KEY
    - account_name -- Batch account name. Alternatively, set by environment variable: AZURE_BATCH_ACCOUNT
    - auto_scale_evaluation_interval -- The default value is 15 minutes. The minimum and maximum value are 5 minutes and 168 hours respectively. If you specify a value less than 5 minutes or greater than 168 hours, the Batch service rejects the request with an invalid property value error; if you are calling the REST API directly, the HTTP status code is 400 (Bad Request). If you specify a new interval, then the existing autoscale evaluation schedule will be stopped and a new autoscale evaluation schedule will be started, with its starting time being the time when this request was issued.
    - auto_scale_formula -- The formula is checked for validity before it is applied to the Pool. If the formula is not valid, the Batch service rejects the request with detailed error information. For more information about specifying this formula, see Automatically scale Compute Nodes in an Azure Batch Pool (https://azure.microsoft.com/en-us/documentation/articles/batch-automatic-scaling).
    - if_match -- An ETag value associated with the version of the resource known to the client. The operation will be performed only if the resource's current ETag on the service exactly matches the value specified by the client.
    - if_modified_since -- A timestamp indicating the last modified time of the resource known to the client. The operation will be performed only if the resource on the service has been modified since the specified time.
    - if_none_match -- An ETag value associated with the version of the resource known to the client. The operation will be performed only if the resource's current ETag on the service does not match the value specified by the client.
    - if_unmodified_since -- A timestamp indicating the last modified time of the resource known to the client. The operation will be performed only if the resource on the service has not been modified since the specified time.
    '''
    return _call_az("az batch pool autoscale enable", locals())


def evaluate(auto_scale_formula, pool_id, account_endpoint=None, account_key=None, account_name=None):
    '''
    

    Required Parameters:
    - auto_scale_formula -- The formula is validated and its results calculated, but it is not applied to the Pool. To apply the formula to the Pool, 'Enable automatic scaling on a Pool'. For more information about specifying this formula, see Automatically scale Compute Nodes in an Azure Batch Pool (https://azure.microsoft.com/en-us/documentation/articles/batch-automatic-scaling).
    - pool_id -- The ID of the Pool on which to evaluate the automatic scaling formula.

    Optional Parameters:
    - account_endpoint -- Batch service endpoint. Alternatively, set by environment variable: AZURE_BATCH_ENDPOINT
    - account_key -- Batch account key. Alternatively, set by environment variable: AZURE_BATCH_ACCESS_KEY
    - account_name -- Batch account name. Alternatively, set by environment variable: AZURE_BATCH_ACCOUNT
    '''
    return _call_az("az batch pool autoscale evaluate", locals())




'''
Manage Azure Cosmos DB keys.
'''
from ... pyaz_utils import _call_az

def list(name, resource_group, type=None):
    '''
    List the access keys or connection strings for a Azure Cosmos DB database account.

    Required Parameters:
    - name -- Cosmosdb account name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - type -- The type of account key.
    '''
    return _call_az("az cosmosdb keys list", locals())


def regenerate(key_kind, name, resource_group):
    '''
    Regenerate an access key for a Azure Cosmos DB database account.

    Required Parameters:
    - key_kind -- The access key to regenerate.
    - name -- Name of the Cosmos DB database account
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cosmosdb keys regenerate", locals())




from ... pyaz_utils import _call_az

def list(name, resource_group):
    '''
    Get the Network access control of SignalR Service.

    Required Parameters:
    - name -- Name of signalr service.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az signalr network-rule list", locals())


def update(name, resource_group, allow=None, connection_name=None, deny=None, public_network=None):
    '''
    Update the Network access control of SignalR Service.

    Required Parameters:
    - name -- Name of signalr service.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - allow -- The allowed virtual network rule. Space-separeted list of scope to assign. Allowed values: ClientConnection, ServerConnection, RESTAPI
    - connection_name -- Space-separeted list of private endpoint connection name.
    - deny -- The denied virtual network rule. Space-separeted list of scope to assign. Allowed values: ClientConnection, ServerConnection, RESTAPI
    - public_network -- Set rules for public network.
    '''
    return _call_az("az signalr network-rule update", locals())




'''
View your security assessment results.
'''
from ... pyaz_utils import _call_az

def list():
    '''
    List all security assessment results.
    '''
    return _call_az("az security assessment list", locals())


def show(name, assessed_resource_id=None):
    '''
    Shows a security assessment.

    Required Parameters:
    - name -- name of the resource to be fetched

    Optional Parameters:
    - assessed_resource_id -- The target resource for this assessment
    '''
    return _call_az("az security assessment show", locals())


def create(name, status_code, additional_data=None, assessed_resource_id=None, status_cause=None, status_description=None):
    '''
    Creates a customer managed security assessment.

    Required Parameters:
    - name -- name of the resource to be fetched
    - status_code -- Progremmatic code for the result of the assessment. can be "Healthy", "Unhealthy" or "NotApplicable"

    Optional Parameters:
    - additional_data -- Data that is attached to the assessment result for better investigations or status clarity
    - assessed_resource_id -- The target resource for this assessment
    - status_cause -- Progremmatic code for the cause of the assessment result
    - status_description -- Human readable description of the cause of the assessment result
    '''
    return _call_az("az security assessment create", locals())


def delete(name, assessed_resource_id=None):
    '''
    Deletes a security assessment.

    Required Parameters:
    - name -- name of the resource to be fetched

    Optional Parameters:
    - assessed_resource_id -- The target resource for this assessment
    '''
    return _call_az("az security assessment delete", locals())

